# -*- coding: utf-8 -*-

"""Cryptographic data provider."""

import hashlib
import secrets
import uuid

from mimesis.enums import Algorithm
from mimesis.providers.base import BaseProvider
from mimesis.providers.text import Text

__all__ = ['Cryptographic']


class Cryptographic(BaseProvider):
    """Class that provides cryptographic data."""

    def __init__(self, *args, **kwargs) -> None:
        """Initialize attributes.

        :param seed: Seed.
        """
        super().__init__(*args, **kwargs)
        self.__words = Text('en')._data.get('words', {})

    def uuid(self, version: int = None) -> str:
        """Generate random UUID.

        :param version: UUID version.
        :return: UUID
        """
        bits = self.random.getrandbits(128)
        return str(uuid.UUID(int=bits, version=version))

    def hash(self, algorithm: Algorithm = None) -> str:  # noqa: A003
        """Generate random hash.

        To change hashing algorithm, pass parameter ``algorithm``
        with needed value of the enum object :class:`~mimesis.enums.Algorithm`

        :param algorithm: Enum object :class:`~mimesis.enums.Algorithm`.
        :return: Hash.
        :raises NonEnumerableError: if algorithm is not supported.
        """
        key = self._validate_enum(algorithm, Algorithm)

        if hasattr(hashlib, key):
            fn = getattr(hashlib, key)
            return fn(self.uuid().encode()).hexdigest()

    @staticmethod
    def token_bytes(entropy: int = 32) -> bytes:
        """Generate byte string containing ``entropy`` bytes.

        The string has ``entropy`` random bytes, each byte
        converted to two hex digits.

        .. warning:: Seed is not applicable to this method,
            because of its cryptographic-safe nature.


        :param entropy: Number of bytes (default: 32).
        :return: Random bytes.
        """
        return secrets.token_bytes(entropy)

    @staticmethod
    def token_hex(entropy: int = 32) -> str:
        """Return a random text string, in hexadecimal.

        The string has *entropy* random bytes, each byte converted to two
        hex digits.  If *entropy* is ``None`` or not supplied, a reasonable
        default is used.

        .. warning:: Seed is not applicable to this method,
            because of its cryptographic-safe nature.

        :param entropy: Number of bytes (default: 32).
        :return: Token.
        """
        return secrets.token_hex(entropy)

    @staticmethod
    def token_urlsafe(entropy: int = 32):
        """Return a random URL-safe text string, in Base64 encoding.

        The string has *entropy* random bytes.  If *entropy* is ``None``
        or not supplied, a reasonable default is used.

        .. warning:: Seed is not applicable to this method,
            because of its cryptographic-safe nature.

        :param entropy: Number of bytes (default: 32).
        :return: URL-safe token.
        """
        return secrets.token_urlsafe(entropy)

    def mnemonic_phrase(self, length: int = 12) -> str:
        """Generate pseudo mnemonic phrase.

        :param length: Number of words.
        :return: Mnemonic code.
        """
        words = self.__words['normal']
        return ' '.join(self.random.choice(words) for _ in range(length))



# -*- coding: utf-8 -*-

"""This module is provide internal util functions."""

import ssl
from os import path
from typing import Union
from urllib import request
from uuid import uuid4

__all__ = ['download_image', 'luhn_checksum']


def luhn_checksum(num: str) -> str:
    """Calculate a checksum for num using the Luhn algorithm.

    :param num: The number to calculate a checksum for as a string.
    :return: Checksum for number.
    """
    check = 0
    for i, s in enumerate(reversed(num)):
        sx = int(s)
        sx = sx * 2 if i % 2 == 0 else sx
        sx = sx - 9 if sx > 9 else sx
        check += sx
    return str(check * 9 % 10)


def download_image(url: str = '', save_path: str = '',
                   unverified_ctx: bool = False) -> Union[None, str]:
    """Download image and save in current directory on local machine.

    :param url: URL to image.
    :param save_path: Saving path.
    :param unverified_ctx: Create unverified context.
    :return: Path to downloaded image.
    :rtype: str or None
    """
    if unverified_ctx:
        ssl._create_default_https_context = ssl._create_unverified_context

    if url:
        image_name = url.rsplit('/')[-1]

        splitted_name = image_name.rsplit('.')
        if len(splitted_name) < 2:
            image_name = '{}.jpg'.format(uuid4())
        else:
            image_name = '{}.{}'.format(uuid4(), splitted_name[-1])
        full_image_path = path.join(save_path, image_name)
        request.urlretrieve(url, full_image_path)
        return full_image_path
    return None



# -*- coding: utf-8 -*-

"""Custom types and shortcuts for annotating Mimesis."""

import datetime
from typing import Any, Dict, Union

__all__ = [
    'JSON',
    'DateTime',
    'Timestamp',
    'Time',
    'Date',
    'Seed',
]

JSON = Dict[str, Any]

DateTime = datetime.datetime

Time = datetime.time

Date = datetime.date

Timestamp = Union[str, int]

Seed = Union[int, str, bytes, bytearray]



# -*- coding: utf-8 -*-

"""Provides all the generic data related to the personal information."""

BLOOD_GROUPS = (
    'O+',
    'A+',
    'B+',
    'AB+',
    'O−',
    'A−',
    'B−',
    'AB−',
)

GENDER_SYMBOLS = (
    '♂',
    '♀',
    '⚲',
)

SEXUALITY_SYMBOLS = (
    '⚤',
    '⚢',
    '⚣',
    '⚥',
    '⚧',
    '⚪',
)

USERNAMES = _ = [
    'deemphasize', 'creamier', 'apatosaurus', 'disorderer', 'unjamming',
    'erection', 'duckwalk', 'fluxional', 'anthems', 'partridge', 'cessna',
    'dove', 'vomitorium', 'dabber', 'cytherea', 'imper', 'bargeman',
    'appleblossom', 'agnail', 'ultramaximal', 'comate', 'nuanced', 'pelican',
    'hydrothermal', 'binghi', 'triplocaulescent', 'emu', 'exert', 'condurango',
    'anime', 'expresso', 'unmelted', 'dachshund', 'trachytes',
    'undistinguished', 'unerroneous', 'coagulate', 'calvary', 'sexualized',
    'annie', 'birthmark', 'chivalric', 'subcompletion', 'analytic', 'expone',
    'bluefin', 'adhesive', 'circuits', 'hiatus', 'baronesses', 'behead',
    'breakwater', 'quibblers', 'spaciously', 'aback', 'taurocholate',
    'abominable', 'ethenyl', 'deformative', 'vituperative', 'scroll', 'garbs',
    'bellmaker', 'tibouchina', 'spratted', 'echidna', 'humiliation', 'section',
    'becke', 'saltee', 'counterclaims', 'orthopathically', 'blows',
    'salpingopharyngeus', 'amalgamation', 'scarcity', 'champing', 'aceology',
    'andirin', 'carmencita', 'landowning', 'backcross', 'cheirospasm',
    'unstrict', 'coward', 'balcom', 'eunice', 'crabber', 'respirometric',
    'oliphant', 'folkmotes', 'abidal', 'astonishing', 'lazying', 'supershow',
    'sherramoor', 'molly', 'chetan', 'cakiest', 'carambole', 'armourer',
    'awake', 'snuffliness', 'whitherso', 'blackest', 'deviated', 'sapid',
    'scissor', 'wooled', 'phaenogamous', 'sclera', 'ratiocinator', 'heft',
    'doubledecker', 'cocaine', 'dotted', 'enneateric', 'festellae', 'adinole',
    'peachen', 'denny', 'blanch', 'recurrent', 'drier', 'seatbelts', 'breaster',
    'azoic', 'ternatisect', 'beate', 'clamorousness', 'ermey', 'shrimpier',
    'mycoplana', 'crabby', 'cozen', 'eventfully', 'finnmarks',
    'electropsychrometer', 'peddles', 'chanteuse', 'madonna', 'geologizing',
    'symphoricarpos', 'desecration', 'catbird', 'pellitories', 'elianora',
    'underproduction', 'embrica', 'elaterist', 'ruptuary', 'codeias',
    'offsprings', 'upstages', 'ameliorators', 'brushy', 'oncogene', 'midwifes',
    'seaflood', 'dislocator', 'toner', 'unpurchasable', 'ulonata', 'quintefoil',
    'unmatchableness', 'barit', 'outfame', 'dougall', 'seaters', 'pintada',
    'methylglyoxal', 'exodium', 'transplace', 'redoxes', 'trajects', 'recrank',
    'brune', 'herve', 'inviscidity', 'consul', 'aerobatic', 'chinaberry',
    'blinkered', 'septenate', 'cornmuse', 'alene', 'fluyt', 'sperate',
    'tannined', 'incompletion', 'macaw', 'viva', 'dumas', 'painterly',
    'durmast', 'amril', 'balas', 'costs', 'bloodiest', 'decision', 'waiting',
    'hoddens', 'dogman', 'emmetropism', 'snowshoe', 'gingiva', 'spiderling',
    'collie', 'dreyfus', 'obfuscable', 'brambles', 'arock', 'adsorption',
    'cebus', 'hyalinization', 'aplysia', 'hopeful', 'merry', 'angelate',
    'bedrooms', 'trapezial', 'alogism', 'collisions', 'beagle', 'brachylogy',
    'debased', 'molar', 'eldreth', 'beechy', 'coseat', 'monkeyshines',
    'myrmecoid', 'crane', 'halbert', 'sheeting', 'curver', 'oedipus',
    'polypage', 'preoblige', 'ceratium', 'rooky', 'maxillas', 'bagrationite',
    'claudicate', 'brach', 'breaker', 'fletcher', 'deanery', 'overexpanded',
    'argentamin', 'cutthroat', 'balletomane', 'cypher', 'nete', 'bhava',
    'biochemical', 'distressedly', 'nondeafened', 'emendating', 'ludlovian',
    'elbow', 'drugless', 'lardoon', 'beachwear', 'acrorhagus', 'wakerife',
    'aptitude', 'knaw', 'amber', 'optimize', 'aqueduct', 'boards', 'biker',
    'aubert', 'ingots', 'landlords', 'bevin', 'cathedrals', 'gobbet', 'ackey',
    'invict', 'electrolysis', 'palmar', 'cavalero', 'thob', 'patching',
    'berkelium', 'autobiographal', 'kwashiorkor', 'bastion', 'adventurer',
    'uvulectomy', 'awave', 'rothesay', 'cayapa', 'ox', 'agaty', 'tutelae',
    'anthonis', 'uncool', 'eulalie', 'kickxia', 'jug', 'ciscos', 'pleiocene',
    'intertrigo', 'bouncer', 'cornhusks', 'seism', 'chatting', 'arsenium',
    'secretor', 'lucidity', 'freezing', 'pastis', 'potsie', 'gopher',
    'dairyman', 'hoising', 'bornagain', 'needlewomen', 'shaping', 'alleyway',
    'caballero', 'switchers', 'unlassoed', 'roaming', 'encomic', 'semesters',
    'carolus', 'hachment', 'named', 'clockhouse', 'acana', 'wards',
    'regularity', 'unmolified', 'comfort', 'clubs', 'jotisi', 'chieftain',
    'brennand', 'unmet', 'avuncular', 'achromic', 'dehaan', 'crusty', 'museful',
    'torpedos', 'amaryllis', 'fortepiano', 'cormac', 'ambarella',
    'semiquadrate', 'dynamistic', 'immunology', 'acrid', 'gwerziou', 'antipart',
    'deepfreezed', 'byran', 'highheartedly', 'armado', 'tralatitious',
    'blazers', 'caplin', 'outside', 'analogue', 'unconformableness',
    'hottentot', 'athene', 'interscene', 'unshadily', 'uncassock', 'antivenom',
    'stork', 'annamaria', 'kibbutz', 'refertilizing', 'pennyroyal', 'buckeye',
    'carlet', 'winkingly', 'vocationalism', 'hypoergic', 'navaids',
    'trickiness', 'deanthropomorphism', 'expiry', 'cithara', 'enrapted',
    'lepidopter', 'trichloromethane', 'basements', 'edenize', 'hyracina',
    'butterfish', 'prevaluation', 'prolongating', 'bolio', 'inspector',
    'cauchy', 'sarcolytic', 'tutorial', 'brothier', 'walrus', 'shrew', 'ticky',
    'endocyemate', 'begley', 'subpatroness', 'spacial', 'ascalabota', 'jenny',
    'focally', 'dosanjh', 'pachyhymenia', 'dunder', 'baccalaureate',
    'predigital', 'didactic', 'asarin', 'triceratopses', 'propositi',
    'unappeasedness', 'cannibals', 'abbotships', 'corporality',
    'nonexpeditiousness', 'atpco', 'become', 'irrelevantly', 'scattershot',
    'sulphurage', 'azophenol', 'troad', 'casey', 'deathweed', 'quackster',
    'hieracosphinxes', 'evolutionism', 'cruising', 'bulgaria', 'stoat',
    'uneducate', 'catamenia', 'inconditionate', 'contemptuous', 'amontillado',
    'alger', 'absorbed', 'unicist', 'arcus', 'beefsteak', 'hellion', 'smokers',
    'converses', 'bahamian', 'damocles', 'bulldog', 'daisi', 'guars', 'bursate',
    'endrys', 'defloration', 'eyeballs', 'acoustic', 'business', 'nixy',
    'rumshop', 'mouths', 'hiding', 'ecthyma', 'cameo', 'conserver', 'analyst',
    'brogues', 'barong', 'bookworm', 'votresses', 'calcine', 'charging',
    'couplet', 'doodad', 'plainswomen', 'aztecs', 'debatement', 'buttered',
    'dhooras', 'ambitions', 'orpheus', 'ad', 'broddy', 'curley', 'chemistry',
    'elsey', 'mogul', 'phasianinae', 'cholophaein', 'bigwig', 'verbenaceae',
    'numbat', 'negativist', 'digraph', 'creecy', 'feedbacks', 'carpetbags',
    'sympathetoblast', 'espied', 'supergeneric', 'dennie', 'decayed',
    'aspherical', 'adders', 'affenpinscher', 'qibla', 'irony', 'bunchberry',
    'palesman', 'clockwise', 'preprudently', 'agnar', 'armando', 'rebrace',
    'fanmaker', 'bloodsports', 'gharial', 'primeval', 'killas', 'kilohertz',
    'pederasts', 'hodad', 'castles', 'facer', 'capozzi', 'porkpie',
    'velocipeded', 'canto', 'amgad', 'decking', 'robin', 'sportsmen',
    'stereotype', 'appleton', 'endoperidial', 'grundyite', 'algedi', 'goladar',
    'unimitated', 'disorganise', 'kooks', 'antarctical', 'dinny',
    'proattendance', 'british', 'intrigued', 'ultima', 'coeducate', 'dobras',
    'puma', 'atique', 'cyamus', 'aquaria', 'pleasurably', 'brynn',
    'presecuring', 'campane', 'blotlessness', 'automatic', 'dugong',
    'epicentral', 'absent', 'antlike', 'crozer', 'schmelze', 'delectated',
    'weld', 'drink', 'sander', 'inequality', 'preacquiring', 'chameleons',
    'snails', 'superstoically', 'sociables', 'indetermined', 'bambie',
    'davidian', 'utterancy', 'briel', 'aliyah', 'redpanda', 'chela', 'sheep',
    'uppercut', 'mithraize', 'affiliate', 'adumbrations', 'mastoid',
    'proveditor', 'divest', 'sanded', 'magirologist', 'confederacy',
    'watercolors', 'crataegus', 'swilltub', 'boyar', 'bowlful', 'ashlar',
    'dinner', 'cudgeled', 'signification', 'ribbon', 'gameness',
    'gregariousness', 'eskimo', 'ablution', 'coghlan', 'unalterable', 'unties',
    'speechlessly', 'scarabs', 'controversal', 'raias', 'tabloids', 'blackens',
    'umbrate', 'broking', 'outportion', 'chambertin', 'combaz', 'coeval',
    'bajury', 'antonym', 'distinctive', 'unlibellously', 'boomerang', 'quott',
    'exploiters', 'drescher', 'uniembryonate', 'creative', 'complex',
    'turkophil', 'joiningly', 'siamese', 'seiser', 'hechsherim', 'blissfully',
    'precognition', 'barse', 'awful', 'artiste', 'pourer', 'emera', 'euectic',
    'fettuccine', 'acryl', 'crucify', 'importers', 'dayton', 'pentameridae',
    'eriksson', 'brandice', 'cynthy', 'cornishman', 'celebrity', 'pimplinae',
    'amphithuron', 'cassat', 'shambled', 'cornice', 'antibiotic', 'splendent',
    'donica', 'ephialtes', 'hydromyelocele', 'tegment', 'yaird',
    'overgratefulness', 'greener', 'imbued', 'caballer', 'dominiqu', 'loudness',
    'randir', 'cowtail', 'monotrochian', 'deena', 'theologer', 'dusun',
    'consciences', 'correal', 'holloo', 'batten', 'usself', 'darker',
    'pedocalcic', 'neutrologistic', 'benward', 'bagpipes', 'aluta',
    'pterodactylus', 'thingumadoodle', 'abrupt', 'abstain', 'breathless',
    'xyloquinone', 'tarsier', 'angeleyes', 'differences', 'launce', 'chimbley',
    'asoka', 'bares', 'appliable', 'bronchiole', 'malices', 'siennas',
    'pioneering', 'earles', 'spawners', 'birretta', 'knurly', 'fabler',
    'undermined', 'badju', 'starlessly', 'ewing', 'acrook', 'conceit', 'egret',
    'mussitation', 'adorable', 'riced', 'jyngine', 'passwords', 'antivirus',
    'chipmunk', 'amorist', 'syncretion', 'callianassidae', 'barclay', 'poesy',
    'nonseparable', 'nonprotractile', 'explosion', 'shandies', 'erbach',
    'scalet', 'globefish', 'staurotide', 'biedermeier', 'uakari', 'alcoa',
    'arzun', 'reformat', 'coxswain', 'anathemas', 'consolute', 'amines',
    'pasquilant', 'caterpillars', 'blazon', 'auspicious', 'outscouring',
    'zonkey', 'annale', 'jophiel', 'poetess', 'nonesthetic', 'jarbird',
    'tobacconist', 'closterium', 'deluxe', 'transportables', 'handbasket',
    'seldom', 'cod', 'clerks', 'asthenopia', 'aisling', 'malpracticing',
    'epomophorus', 'amarvel', 'solvus', 'havocs', 'reaper', 'neurin', 'bombay',
    'wormer', 'toad', 'apaches', 'polyandrism', 'completing', 'caron', 'asleep',
    'antimachine', 'blacktongue', 'tympanectomy', 'dirigent', 'concordancy',
    'ockster', 'undertaken', 'lectures', 'pachytene', 'trafflike', 'cycloids',
    'dresser', 'surrey', 'exciton', 'abrin', 'pedlers', 'toppingly',
    'bluestocking', 'pigwash', 'unirritableness', 'overdogs', 'coatimundi',
    'abstruseness', 'infest', 'pyrrhic', 'grouse', 'seining', 'arthuriana',
    'colon', 'defeatism', 'reddeer', 'goldfinch', 'shantey', 'chasing',
    'churinga', 'amelina', 'memorableness', 'impala', 'miasmatize', 'mosks',
    'chuser', 'acidic', 'converse', 'misnames', 'anemone', 'dickerson',
    'fiercely', 'denice', 'fores', 'stickups', 'navite', 'bullfrog', 'brann',
    'diploplaculate', 'benefactory', 'willowweed', 'unhideable', 'souletin',
    'irregular', 'achmetha', 'paulista', 'cation', 'huddled', 'docherty',
    'cinderel', 'disheart', 'pigeon', 'stallions', 'fox', 'cequi', 'troughlike',
    'mischieve', 'hoops', 'sauncy', 'coyish', 'scheduler', 'adman', 'blasphemy',
    'tastier', 'celebrations', 'busch', 'alvine', 'overgoaded', 'ergane',
    'benjie', 'fumous', 'thymol', 'scythed', 'sassiest', 'sandgoby', 'lotas',
    'marriers', 'banat', 'corie', 'axoplasms', 'jalop', 'branch',
    'deforestation', 'ridicule', 'surcease', 'tmeses', 'blazed', 'horometry',
    'catnapers', 'apathetic', 'cloudage', 'sardine', 'pug', 'promisable',
    'arulo', 'ardys', 'riemannian', 'commenced', 'parlay', 'pyoses',
    'chaperone', 'crocodile', 'desirae', 'lieve', 'inmeats', 'poundage',
    'compellable', 'erroll', 'discordia', 'incumbant', 'axenic', 'enciphered',
    'bosom', 'descended', 'berates', 'chimalapa', 'dresel', 'angiotomy',
    'syphilidography', 'magnetooptical', 'alien', 'appetence', 'schistous',
    'duenas', 'semilate', 'us', 'jocund', 'compress', 'caprifigs', 'normality',
    'lyrebird', 'endotropic', 'dichter', 'bryanism', 'imposts', 'dwale',
    'discontiguity', 'bench', 'skims', 'tabid', 'ateles', 'downstreet', 'syed',
    'subfusc', 'trination', 'experimentalist', 'eightsman', 'lallans',
    'nuzzles', 'groundskeep', 'enchanter', 'bolometric', 'fingerlings',
    'deifier', 'erlenmeyer', 'thick', 'pretranscription', 'boldface', 'durrell',
    'nonscraping', 'burek', 'carapo', 'jaborin', 'begladding', 'evensong',
    'oxetone', 'mole', 'pokeroot', 'hillock', 'alexas', 'bonobo', 'cranky',
    'decil', 'madiga', 'chimpanzee', 'dentine', 'ephemeron', 'tuner', 'bigha',
    'sidetracked', 'clowder', 'drizzly', 'camion', 'kakapo', 'cabasset',
    'chivalrous', 'carcass', 'bosomy', 'unexpensive', 'desiri', 'zappiest',
    'iters', 'braggers', 'cashbox', 'cleanup', 'adorer', 'ambsace', 'augeri',
    'equiperiodic', 'nincum', 'scaldy', 'victories', 'binturong',
    'undescendent', 'bogard', 'busby', 'palaearctic', 'sparrow', 'backgammon',
    'beethovenian', 'signal', 'blindeyes', 'cosine', 'aryballi', 'aeschylus',
    'chalumeau', 'leve', 'soapery', 'canthuthi', 'moggie', 'transmissionist',
    'gecko', 'upaithric', 'strawsmall', 'tropidoleptus', 'asters', 'nebaliidae',
    'allegri', 'speculate', 'aymara', 'rovers', 'babak', 'doodlebug', 'ferrous',
    'exponent', 'legate', 'aphasiacs', 'earlier', 'verdurer', 'montrachet',
    'boudreau', 'simoniac', 'boser', 'alligator', 'mesel', 'abrasive',
    'transform', 'lesbians', 'platycerium', 'lemon', 'advocate', 'disilane',
    'mustered', 'notifying', 'dates', 'thrower', 'urinaries', 'demised',
    'pneumatotactic', 'congregant', 'jellyfish', 'oyster', 'mochy',
    'effectible', 'clannishly', 'undethroned', 'skellum', 'agonal', 'ethically',
    'spectrochemical', 'caribou', 'setae', 'decaf', 'devaluation', 'habenaria',
    'debride', 'catheads', 'emball', 'genesitic', 'overshorten', 'vulturelike',
    'dropped', 'hereinabove', 'keynoted', 'deadlocked', 'adena',
    'brachydiagonal', 'atazir', 'brutter', 'actually', 'estevam', 'bardsley',
    'solitude', 'cremone', 'alleluia', 'siciliano', 'blueberries', 'thickened',
    'dalt', 'centuple', 'boing', 'severality', 'alten', 'birdmen',
    'contemptible', 'unsearchable', 'diwata', 'ablaze', 'ambivert', 'demeo',
    'flamingo', 'fish', 'sissoo', 'cobwebs', 'pearmonger', 'drummer', 'galago',
    'djins', 'overjoyed', 'motivator', 'bande', 'bartizan', 'glioma',
    'scirocco', 'shipworms', 'sloth', 'fibrinate', 'bystreet', 'darshi',
    'arcanal', 'polymythic', 'outredden', 'avernal', 'onomatopy', 'selenious',
    'bobotie', 'dragoman', 'buddie', 'boredoms', 'basilosauridae', 'seginus',
    'hamster', 'dreads', 'qqv', 'criterium', 'aquatinta', 'eniac',
    'sacculoutricular', 'perplexed', 'counterdistinct', 'slither', 'elevator',
    'wanton', 'caban', 'ethnobotanic', 'emissary', 'syzygetic', 'detours',
    'episcopalian', 'gummers', 'batara', 'platypus', 'dulcea', 'carrizo',
    'jackal', 'bathed', 'elvera', 'hews', 'scillipicrin', 'orthocentre',
    'thieving', 'dazing', 'chrysanthemum', 'upshove', 'jimjums', 'plote',
    'unseduceability', 'bluebill', 'dogfish', 'brimful', 'battlegrounds',
    'hydrosulphurated', 'bungerly', 'monkey', 'litterbag', 'devest', 'cheering',
    'bubak', 'telautography', 'amberous', 'calcar', 'braddock', 'sculpt',
    'hummingbird', 'naturalists', 'alay', 'blais', 'latria', 'hawk', 'damping',
    'zizyphus', 'corrigan', 'brevier', 'sylvanitic', 'cobol', 'bajau',
    'consummately', 'countor', 'sturmian', 'jayhawker', 'diazoate', 'eyeball',
    'waddie', 'unhappen', 'dunderhead', 'bartram', 'byron', 'pig', 'cuttlefish',
    'nidus', 'hippophagy', 'lynx', 'able', 'myographs', 'pagandoms', 'diena',
    'undelusively', 'tridiapason', 'anilinophilous', 'undoubling', 'borrelli',
    'okinagan', 'nitrosify', 'albuminaturia', 'bloodshedder', 'camber',
    'commanded', 'eggfish', 'adriene', 'aborter', 'louse', 'suum', 'documented',
    'julienite', 'bounder', 'licencer', 'outbargains', 'idolatrous', 'wryest',
    'amour', 'encloud', 'gibbon', 'jurisdictional', 'horsiest', 'qualm',
    'semiticism', 'dumper', 'lemur', 'deuce', 'warthog', 'silicon', 'biotech',
    'heron', 'badminton', 'dawing', 'crackback', 'superpiousness', 'thorpes',
    'stubbles', 'polyscopic', 'scrag', 'dutiful', 'dreader', 'dynamism',
    'workbench', 'worker', 'biomechanics', 'validity', 'bodier', 'worm',
    'centrarchidae', 'slinking', 'diablo', 'giantpanda', 'traist', 'lark',
    'empathic', 'abdominal', 'dupes', 'barragon', 'esposito', 'ballsy',
    'ashore', 'interregnum', 'broody', 'costumey', 'bradley', 'majesty',
    'carayan', 'unphrasableness', 'adapa', 'etalon', 'berenices', 'cambrian',
    'normalcy', 'colene', 'balser', 'zanza', 'abrasiometer', 'overdignifiedly',
    'nodes', 'arteries', 'assimilate', 'pantomime', 'biotechnological',
    'blackleg', 'frettation', 'paludrin', 'spondulics', 'dashed', 'bemole',
    'netlike', 'rufous', 'galagos', 'caricaturists', 'pouncing', 'monkhood',
    'accompanimental', 'misresult', 'millenia', 'cousins', 'sippingly', 'anasa',
    'pulper', 'alloclase', 'stooter', 'shark', 'pityriasis', 'inchoacy',
    'algonquians', 'acronymized', 'bowwow', 'supersaturating', 'archfiend',
    'chimu', 'bluethroat', 'unframeable', 'chadars', 'astonisher',
    'vaucheriaceous', 'caelus', 'wrecker', 'mermnad', 'hornet', 'daleth',
    'falconry', 'degenerative', 'aletaster', 'lining', 'sooners', 'coved',
    'seated', 'industrochemical', 'sided', 'irradiation', 'clifton', 'barriere',
    'deformity', 'cambeva', 'scaled', 'misreckoned', 'bommer', 'miffs',
    'pheasant', 'wallet', 'passalid', 'donkey', 'damaged', 'electrostatic',
    'unprecipitantly', 'outcrawls', 'clubbily', 'tennists', 'optoelectronic',
    'dilbert', 'paseos', 'vaultier', 'cattle', 'alaite', 'althein', 'ammeter',
    'ephyra', 'curite', 'clote', 'chloropalladic', 'detlev', 'habilimented',
    'cricker', 'eliminable', 'grievance', 'mosquito', 'administrate',
    'dribbling', 'externity', 'dieri', 'edwin', 'shakable', 'sivaist',
    'darkener', 'brekel', 'claws', 'rudiment', 'equivocal', 'arundo',
    'squirarchal', 'consecrator', 'budding', 'dipterocarpaceae', 'cointer',
    'carmelite', 'dziemian', 'routeman', 'suffixal', 'dejected', 'abele',
    'skipjack', 'portrayal', 'dosers', 'ladyling', 'subopercle', 'coleopterous',
    'insaneness', 'busybody', 'assistency', 'kurikata', 'maidenhead',
    'poeticised', 'anticyclone', 'exterminatress', 'chicken', 'vulture',
    'hypotrophy', 'dower', 'hydroscopicity', 'looseness', 'millistere',
    'delayer', 'intercoms', 'sculleries', 'unchronological', 'nonswimming',
    'ornithoscopy', 'longa', 'cyclic', 'prophecy', 'cornflake', 'accosting',
    'robbery', 'unpracticable', 'drane', 'solarise', 'colorize', 'darkness',
    'sharklike', 'unvibrating', 'elephantseal', 'malleating', 'metaluminic',
    'bombloads', 'rail', 'tellurium', 'maimed', 'zippier', 'arriba',
    'internship', 'letdown', 'consultant', 'emmey', 'alterant', 'auberge',
    'chancery', 'segment', 'reopen', 'cycloid', 'demiss', 'subrector',
    'wipstock', 'chores', 'labradoodle', 'faceman', 'pituitousness', 'cuisse',
    'imboldening', 'unfailed', 'donned', 'dodie', 'adaptive', 'coquet',
    'kirimon', 'scumble', 'pocketful', 'arley', 'bikini', 'sauerbraten',
    'insular', 'withery', 'codeless', 'alkoxid', 'burlie',
    'polioencephalomyelitis', 'pylorogastrectomy', 'enfeeblish', 'headsmen',
    'orchichorea', 'castoffs', 'cremant', 'cabala', 'lag', 'salaried', 'durrie',
    'thanking', 'imbellic', 'tipping', 'masterstroke', 'onions', 'mongrel',
    'masterly', 'wombat', 'explorers', 'harbourous', 'acetaminol',
    'tapinceophalism', 'cagatay', 'bardolph', 'realty', 'emmaline', 'awoken',
    'countersink', 'cordaites', 'poohing', 'deere', 'bayesian', 'avouch',
    'hygenics', 'beetle', 'benight', 'compunction', 'marsupialia', 'botanical',
    'habanera', 'javanese', 'receipt', 'shott', 'placebos', 'phytosauria',
    'devious', 'sedatives', 'toking', 'takeaway', 'frustrative', 'batis', 'olm',
    'forehead', 'cantoral', 'branchings', 'ceratins', 'cavatina', 'architraves',
    'arisen', 'pixies', 'decoys', 'clandestine', 'culinary', 'butterfly',
    'eamonn', 'goldenest', 'allegiances', 'euphori', 'minae', 'agosto',
    'podial', 'engineers', 'bask', 'trillibub', 'concertizes', 'beatitude',
    'ditrematous', 'strutting', 'haematins', 'enrica', 'massekhoth', 'warship',
    'newborns', 'borderless', 'cherish', 'ebenezer', 'cowkeeper', 'squirrel',
    'tups', 'bromes', 'testimony', 'bufonidae', 'glasses', 'avgas', 'inbounds',
    'divergence', 'detur', 'flits', 'berlitz', 'twinkled', 'murexid',
    'cerebropedal', 'leesing', 'cutline', 'aftercourse', 'arbores', 'crumby',
    'swabble', 'consolidated', 'periappendicitis', 'snakey', 'torot',
    'tunisians', 'theropod', 'cramped', 'oryx', 'kerb', 'devastating',
    'costard', 'aggressive', 'prussic', 'artifactual', 'supratrochlear',
    'belar', 'patrial', 'bitterness', 'anukit', 'opossum', 'astrolabe',
    'avantgarde', 'ann-marie', 'bitter', 'boatly', 'absorbing', 'calinda',
    'pecky', 'assorted', 'disestablismentarianism', 'pennia', 'pinnacle',
    'alterman', 'engineman', 'halites', 'beograd', 'martensitic', 'headship',
    'chafe', 'carinal', 'flabs', 'christl', 'otter', 'orthognathy', 'detour',
    'kilhig', 'aggies', 'motility', 'prolegomenon', 'cranic', 'bedlamite',
    'bobber', 'crony', 'bryophyte', 'dotson', 'enlivenment', 'clarance',
    'failsafe', 'sapient', 'friseur', 'funkia', 'wising', 'betelnut',
    'subinferred', 'stampeded', 'serosa', 'vertebroiliac', 'disgrace',
    'stripling', 'aspiring', 'unhinderingly', 'anthramin', 'precourse',
    'descendents', 'dorsiventral', 'dikkop', 'baptist', 'deprogramming',
    'affeeror', 'towelette', 'woodcock', 'pathogenetic', 'serglobulin',
    'heredipety', 'invised', 'superstardom', 'beshear', 'dragnet', 'subjicible',
    'celarent', 'spoonyism', 'dahoon', 'deliver', 'groundsheet', 'stoper',
    'whale', 'athenor', 'nonmanila', 'greyhen', 'undiscording', 'blisters',
    'passionometer', 'eupeptically', 'airlock', 'archjockey', 'cradler',
    'underreader', 'caregiver', 'levied', 'bayard', 'nepenthe', 'integrate',
    'barkery', 'unaborted', 'postcard', 'akkadian', 'agdistis', 'passe',
    'shelver', 'consultive', 'craftly', 'retractor', 'baetuli', 'gibed',
    'pangasinan', 'planetologic', 'concubitous', 'burin', 'anisotropic',
    'oppose', 'colleague', 'allergy', 'dona', 'azido', 'tupelo', 'duello',
    'atlantis', 'splay', 'hedgehog', 'subelliptic', 'audette', 'anastasia',
    'patroller', 'imply', 'enunciators', 'dredges', 'fly', 'aucan', 'biddie',
    'seapoose', 'conjure', 'diccon', 'agnosia', 'finalized', 'ailing',
    'unconsolable', 'unnestle', 'cadaster', 'clemens', 'bouto', 'essed',
    'italy', 'biasing', 'bronk', 'aggest', 'naviform', 'unremarkable',
    'chinotti', 'debenture', 'cocking', 'horrifiedly', 'interhybridized',
    'ashcake', 'dress', 'cobbra', 'paraflocculus', 'gluconeogenic', 'blent',
    'huffily', 'married', 'glarry', 'malarkeys', 'uninvigoratively',
    'unvulgarized', 'zelkova', 'recipe', 'wilders', 'prefavorably', 'ao',
    'epicenter', 'uncolourable', 'placekick', 'engluts', 'hometown',
    'outsavoring', 'broomer', 'alanine', 'adine', 'dreep', 'lifters', 'rykes',
    'multani', 'wakened', 'crowds', 'tyrantship', 'trijets', 'confucius',
    'phalaropodidae', 'cuculla', 'ballistae', 'bulanda', 'elegances', 'louie',
    'celature', 'enrapt', 'etherize', 'agnatha', 'ungrappling', 'lumen',
    'scorching', 'ragdoll', 'evokes', 'chlorophane', 'chotts', 'larruped',
    'sovite', 'premillenarianism', 'capybara', 'dimension', 'eurasian',
    'adaptable', 'berthe', 'fers', 'pulvinule', 'bridgeman', 'consecrating',
    'carpocarpal', 'identify', 'unconical', 'darrack', 'eland', 'longsomely',
    'bibliographer', 'inducing', 'jacanas', 'seaside', 'millage', 'comiferous',
    'beachman', 'coyle', 'dosser', 'arachnida', 'cybernetic', 'fugio',
    'physiognomist', 'dunks', 'unstupid', 'pancreatitis', 'fabrizio', 'zooks',
    'clamour', 'goat', 'contradistinctive', 'unattractive', 'uttermost',
    'coquitlam', 'egipto', 'unreliable', 'burdensomely', 'dairylea',
    'neogamous', 'arnis', 'somali', 'introspectionism', 'wyling', 'fortes',
    'tortoise', 'kinglet', 'breeds', 'finch', 'twinflower', 'telegrams',
    'anthropogony', 'vises', 'bemoon', 'cheapest', 'enregistering',
    'standardbred', 'dartman', 'scimitar', 'tiptoppishness', 'pitahauerat',
    'stiffish', 'monomania', 'bernice', 'scumbag', 'erasement', 'arrogant',
    'decimalism', 'addressee', 'cheetah', 'adebayo', 'azine', 'chrystal',
    'caatinga', 'camused', 'bouzouki', 'forzando', 'youse', 'crile',
    'utriculariaceae', 'sailmaker', 'earrings', 'emperors', 'epispinal',
    'aloed', 'ringingly', 'perduring', 'vmintegral', 'ass', 'expressio',
    'buckhorn', 'apostrophe', 'fatidical', 'weasel', 'phrenology', 'pronounal',
    'childhood', 'acid', 'refectioner', 'nondyspeptically', 'zoobenthoic',
    'songwriter', 'charrier', 'drift', 'churring', 'nemichthys', 'ineye',
    'noncompetitively', 'croups', 'superurgency', 'tritoma', 'harpy', 'cavish',
    'carella', 'dreamworld', 'dreaminess', 'amused', 'axolotl', 'trinity',
    'nondenotative', 'alcheringa', 'subclans', 'despot', 'balthasar', 'clipper',
    'skeptics', 'refuted', 'atavus', 'hare', 'saltworker', 'cornea', 'annelid',
    'confers', 'awaken', 'colts', 'apples', 'nubigenous', 'cruce', 'lengthen',
    'bannet', 'redias', 'exorcise', 'unwistful', 'jetteau', 'systemic',
    'uncontenting', 'oddnesses', 'mailbox', 'espadon', 'estheticism',
    'barnstormer', 'divus', 'dockyards', 'sketch', 'mongeese', 'batule',
    'semicultivated', 'interlucent', 'algicides', 'brachiopode', 'elkins',
    'wyson', 'superinference', 'darnel', 'temperer', 'broadway', 'aesthesodic',
    'andrease', 'referencing', 'aware', 'wabby', 'utilizer', 'mallard',
    'cinter', 'bewitch', 'arvin', 'titans', 'cytoblast', 'hypercalcemic',
    'anchors', 'evoked', 'coquets', 'abnegative', 'dialectically', 'anthrol',
    'preorganize', 'splacknuck', 'lovebirds', 'capelet', 'chappy',
    'berycomorphi', 'rotavirus', 'irresponsible', 'dekle', 'alumnal', 'hagmane',
    'plasmid', 'aliyos', 'species', 'disgracer', 'semitropic', 'unilamellar',
    'dhangar', 'allocatur', 'backspace', 'bodhi', 'tessera', 'oxalates',
    'collodion', 'polyparies', 'overview', 'acquest', 'camelus', 'antinome',
    'drench', 'alcove', 'chaudhry', 'exegete', 'casualist', 'thrush',
    'abiogenesis', 'chaotic', 'career', 'earthenware', 'uterometer',
    'voyageurs', 'readiness', 'banes', 'intact', 'pulselessness', 'dispatching',
    'damaris', 'depark', 'everard', 'coppered', 'woodpecker', 'bakers', 'bee',
    'alvera', 'arcane', 'columbic', 'untangling', 'beswick', 'brims',
    'bernadette', 'dolman', 'raccoon', 'woodwaxen', 'sixteenths', 'periostosis',
    'apostolize', 'knotlike', 'constantinople', 'astronautic', 'boaster',
    'suedes', 'jasmined', 'efficience', 'escobilla', 'fuligulinae',
    'exhaustedness', 'cuscus', 'tovarish', 'secateurs', 'surreal', 'moorhen',
    'grudge', 'embittered', 'scintillator', 'cahoot', 'anastasis', 'brewages',
    'daceloninae', 'dolomites', 'hysterectomize', 'quasijudicial',
    'trimethylmethane', 'saltboxes', 'ozonic', 'assausive', 'empress', 'trunks',
    'kingdoms', 'adamant', 'anticontagion', 'backers', 'fifes', 'slete',
    'trachea', 'endowed', 'cuirassed', 'cachet', 'resole', 'everyone',
    'naturopathy', 'caraja', 'rearwards', 'emotionalist', 'acuate', 'axled',
    'grasper', 'uranolatry', 'hardline', 'hwy', 'polyphonist', 'dories',
    'birthing', 'kloof', 'aligner', 'danize', 'slub', 'stuber', 'salangid',
    'cat', 'nervimuscular', 'prawn', 'paunchful', 'crow', 'toxicologist',
    'cedric', 'phoniatry', 'compliant', 'cobblers', 'borated', 'widegap',
    'scandic', 'buckman', 'overreached', 'delmor', 'pipsqueak', 'tarmacadam',
    'assentatory', 'angriness', 'outdodges', 'ajar', 'excoriation', 'eleanore',
    'divinely', 'propriety', 'guanaco', 'aromatic', 'propenes', 'trigs',
    'apraxia', 'chaplin', 'coulter', 'yucca', 'blackings', 'monastery',
    'gieaway', 'intermediaries', 'vulgarian', 'crux', 'downs', 'cabral',
    'chances', 'inexplicit', 'immune', 'vermillions', 'allowance', 'agronomial',
    'extrasterile', 'viny', 'biosynthesis', 'clavodeltoid', 'bombsight',
    'anglesmith', 'close', 'citral', 'chanson', 'dilated', 'subnetworks',
    'serratospinose', 'ironwork', 'couma', 'anteal', 'vilification', 'guarded',
    'onomatopoeia', 'architeuthis', 'chisolm', 'dupree', 'erastus', 'drumline',
    'blotto', 'centric', 'gazelle', 'montebrasite', 'crimp', 'equalling',
    'churn', 'swankiness', 'gargantuan', 'reticulose', 'clamber', 'bugbear',
    'compatibilities', 'ceremonies', 'chinamen', 'elk', 'facto', 'built',
    'blanca', 'formaldehyd', 'charta', 'rebelong', 'baggy', 'steadiest',
    'delano', 'barite', 'enviable', 'musician', 'giraffe', 'mpbs', 'peninsulas',
    'barrelfuls', 'antienvironmentalists', 'subcurate', 'droud', 'parorchis',
    'scrod', 'cangle', 'countess', 'griffin', 'propacifist', 'burry',
    'prosobranch', 'brierley', 'dungan', 'hypoiodous', 'elution', 'poverty',
    'comfortable', 'pommies', 'cebil', 'macroprism', 'caterbrawl', 'rubylike',
    'eduard', 'geology', 'doily', 'moralistic', 'decatur', 'holocryptic',
    'chromomere', 'novelette', 'disproportionate', 'monstrify', 'balboa',
    'grunting', 'stong', 'dorsal', 'binman', 'darics', 'albata', 'yealing',
    'consonantic', 'bullen', 'deputes', 'repair', 'lepargylic', 'trilled',
    'aboard', 'gript', 'mavie', 'microcopied', 'objectionably', 'discount',
    'treacly', 'antuan', 'pensionership', 'photogenous', 'crumblier', 'corners',
    'cashana', 'nickers', 'kingliest', 'canaller', 'camel', 'aquatic', 'bevvy',
    'capitalism', 'everyman', 'positive', 'adorn', 'murmuringly', 'oxeyes',
    'indri', 'unincestuous', 'multijet', 'lubberliness', 'magirological',
    'smoldering', 'spleetnew', 'laryngismal', 'alkalurops', 'hoya', 'leafy',
    'algaesthesis', 'abime', 'cristie', 'mesothetic', 'computerise',
    'flightless', 'pianograph', 'bookmaker', 'kamassi', 'calepin', 'eyeshot',
    'callorhynchus', 'cosmetic', 'waysider', 'deer', 'beleaguering', 'chichi',
    'irater', 'ancon', 'breaklist', 'basset', 'tracking', 'arana', 'plemochoe',
    'goalposts', 'surrounded', 'brownlee', 'shirtdress', 'reinterference',
    'recalcitrating', 'elinor', 'congregate', 'misunderstandable',
    'undercarter', 'wichtisite', 'milled', 'schuit', 'monopodes', 'earth',
    'unadmonished', 'phthalein', 'dolphin', 'signor', 'ballers', 'wineier',
    'admissions', 'daaboul', 'cristina', 'hebete', 'cryptography',
    'mismeasurement', 'troutiest', 'businesswoman', 'thorax', 'unpermeating',
    'craving', 'abridged', 'bosset', 'cheng', 'kamikaze', 'shrimp', 'caseloads',
    'kittenship', 'lithosol', 'achira', 'culled', 'couple', 'argument',
    'forgoer', 'scabs', 'burrower', 'abusive', 'ranchlike', 'emilios', 'gambol',
    'tortulaceous', 'sabed', 'cajuputs', 'births', 'tapadera', 'untinctured',
    'arsonium', 'heptarch', 'continuum', 'underling', 'abortive', 'crinkly',
    'badge', 'abscess', 'athrocyte', 'overfragmented', 'moguls', 'ashpan',
    'utilize', 'outplodding', 'cuarenta', 'scruff', 'overbrush', 'furbished',
    'superanimal', 'emmenagogue', 'chankings', 'alkyds', 'eulalia', 'gnu',
    'scandalisation', 'herring', 'vibrational', 'gaffe', 'copious', 'gaur',
    'autogiro', 'webster', 'ant', 'clink', 'millipede', 'calabari',
    'digestives', 'juliennes', 'carpool', 'darrin', 'nonearning', 'biomagnetic',
    'repopulated', 'customize', 'equiped', 'nonphysiologically', 'theek',
    'censorial', 'kangaroo', 'rodolphus', 'pyruloid', 'duckies', 'insect',
    'arcturia', 'dedicates', 'pacas', 'contrary', 'chavender', 'penstemon',
    'neurovaccination', 'haddock', 'mirbane', 'clarichord', 'esq', 'snuffing',
    'chrysant', 'cobblerless', 'inwall', 'meanwhile', 'cyclothyme', 'benedicta',
    'immun', 'trustees', 'borsht', 'swan', 'aptness', 'tammies', 'haddest',
    'unboldly', 'labrus', 'sillyhow', 'suzerain', 'hyena', 'dacca', 'peller',
    'achaean', 'anteater', 'capricornus', 'downtown', 'dicastic', 'agnoite',
    'plovers', 'precollegiate', 'unfrequentable', 'domination', 'persian',
    'thwartship', 'galopade', 'moirai', 'defoliant', 'husk', 'llama', 'casas',
    'beccafico', 'chalot', 'cyborgs', 'endang', 'saltish', 'albus', 'colombian',
    'rattlesnake', 'intersoil', 'mechanic', 'streamliner', 'invected',
    'bellwood', 'adolph', 'volvas', 'thoracicohumeral', 'feoffee',
    'listeriosis', 'depicting', 'congregationist', 'berossos', 'drainage',
    'esson', 'podagry', 'suspected', 'improve', 'illano', 'hemoglobin',
    'bourguig', 'politics', 'dragonfly', 'jogging', 'beshir', 'peaceable',
    'atoning', 'elusory', 'alchimy', 'thurnia', 'burps', 'afternight',
    'dayspring', 'didani', 'astomia', 'biteme', 'costed', 'greyhound', 'stelic',
    'atomizers', 'highbrows', 'trypaneidae', 'chamois', 'credendum', 'wastiest',
    'artemis', 'instructorless', 'prune', 'brimborion', 'dingo', 'peculated',
    'holts', 'keyless', 'newfoundland', 'nurls', 'graybeard', 'abiezer',
    'hemistater', 'princesse', 'snidest', 'nonrefutation', 'mayfly',
    'shearwater', 'corvettes', 'pluviography', 'cercocebus', 'palookas',
    'bellboy', 'nonseriousness', 'entitledness', 'credenza', 'padauk',
    'intraoral', 'christoffel', 'tandoori', 'proface', 'spaller', 'carlock',
    'burial', 'extremal', 'apama', 'efficient', 'protesting', 'primiparity',
    'bolas', 'attrition', 'anionics', 'insuree', 'defrance', 'smackers',
    'squamosozygomatic', 'disbelief', 'herrengrundite', 'achamma', 'spice',
    'cheques', 'afraid', 'harpoonlike', 'superdistention', 'erudition',
    'hypocoristical', 'blackbirds', 'highflier', 'bouche', 'ameed',
    'electrified', 'syllogist', 'electromassage', 'restrict', 'boodie',
    'emollient', 'acanthurus', 'idiosyncrasy', 'embay', 'algorithms',
    'induviae', 'buder', 'corabelle', 'spelter', 'deposit', 'publicness',
    'efficacious', 'toughening', 'tamias', 'squibling', 'psychognosy',
    'lemonweed', 'gastrohysterorrhaphy', 'lease', 'subject', 'dapped', 'attice',
    'ether', 'usaron', 'pseudonym', 'hypotrochanteric', 'beaverish', 'crullers',
    'crab', 'polystylar', 'diaphane', 'vineal', 'acanth', 'blowy', 'basis',
    'amberoid', 'ambush', 'dewitte', 'janitors', 'chelidonic', 'theolepsy',
    'decries', 'chops', 'deciduate', 'deidre', 'unmodifiableness', 'dropsywort',
    'suprachorioidal', 'relaces', 'formene', 'overurbanization', 'glowfly',
    'pantheistical', 'encenter', 'parser', 'bossman', 'concentrate', 'plasmic',
    'etheline', 'matrimonii', 'multirooted', 'accessible', 'alcindor',
    'achates', 'abroad', 'cordoba', 'semicomical', 'auric', 'periodontology',
    'borane', 'comprehensibly', 'sleekier', 'bibliomane', 'hydroponics',
    'choosey', 'costuming', 'greylag', 'imagining', 'schradan', 'explorations',
    'asteria', 'bossa', 'nongaseous', 'divots', 'bothersome', 'dependent',
    'hooklike', 'craney', 'prerefine', 'seaward', 'hydroxyurea', 'calista',
    'cololite', 'copperleaf', 'eyeglasses', 'goatroot', 'cushing', 'falchion',
    'verdi', 'amok', 'woodcrafty', 'brackets', 'occults', 'clownery', 'barkier',
    'jaguar', 'taunting', 'occidentalism', 'indifferent', 'uneffusing',
    'condom', 'flossie', 'coyote', 'restlessness', 'casselty', 'tartanas',
    'cheetham', 'ostrich', 'intervascular', 'xylon', 'paratrophy', 'bonita',
    'jovicentrical', 'benares', 'intradepartment', 'thoughtfree',
    'unapplicable', 'erithacus', 'livyer', 'bridges', 'annalisa', 'dispraiser',
    'areopagite', 'barrels', 'encephaloscopy', 'paraphrast', 'boose',
    'hayforks', 'endocrinopathic', 'kabiki', 'cobble', 'galactosis', 'rousseau',
    'rottweiler', 'manning', 'scarped', 'salamander', 'ecdemite', 'paidle',
    'clarita', 'contributiveness', 'drunks', 'bicentenarnaries', 'phonetical',
    'thermoplastics', 'balatron', 'seconds', 'nappy', 'dejan', 'unbesmeared',
    'definitized', 'madames', 'boobies', 'kouprey', 'viceless', 'markhor',
    'wafer', 'welcome', 'rubrication', 'dingley', 'cusumano', 'kilometrage',
    'deeann', 'wared', 'chaffiness', 'ardith', 'draconis', 'illegal', 'alleged',
    'exaggerating', 'moratoria', 'emogene', 'topkick', 'charmeuse', 'baghdadi',
    'boars', 'cockled', 'chaudry', 'contribution', 'educable', 'nebraskan',
    'kingfisher', 'avalanche', 'bandager', 'papillon', 'kankie', 'overbrim',
    'racker', 'unladylike', 'seise', 'mazard', 'allgood', 'oxymomora',
    'dabblingly', 'yeanling', 'methyl', 'display', 'polyphone', 'breezing',
    'hump', 'designers', 'abominated', 'discriminant', 'emerized', 'berri',
    'computer', 'heathrman', 'dovelet', 'colloid', 'ecstasy', 'auroras',
    'overarching', 'blackbelly', 'dangersome', 'benzole', 'peery', 'sak',
    'forger', 'actiniochrome', 'protomartyr', 'pauses', 'afterglow', 'courante',
    'pullover', 'pendative', 'alyre', 'prefacers', 'confessions', 'epical',
    'painful', 'chiasma', 'bongos', 'clam', 'corbett', 'enravishes',
    'clapboarding', 'sponge', 'echard', 'sebasic', 'realest', 'desolates',
    'rabbit', 'noncircuit', 'croak', 'chemotherapeutics', 'patter', 'arias',
    'remake', 'relentless', 'hypertrophic', 'orbitar', 'dioptrically', 'dropsy',
    'ballroom', 'chelone', 'causes', 'oxides', 'unripening', 'solatia',
    'repassable', 'danceable', 'snarling', 'chiquito', 'broom', 'serines',
    'pewit', 'ezekiel', 'staple', 'oxbow', 'elizabethan', 'wries', 'pager',
    'chunkiest', 'gunslinger', 'scourer', 'coyan', 'hemopathy', 'kiwi',
    'butting', 'idiots', 'overshroud', 'masseurs', 'escalus', 'sundrily',
    'regauges', 'nuciculture', 'burstones', 'weinmannia', 'zonular', 'necrosis',
    'jostler', 'disciplinarianism', 'averardo', 'conniption', 'caelum', 'gonzo',
    'canberra', 'feminist', 'pedophile', 'curcuma', 'dullhead', 'cladocera',
    'durovic', 'piranha', 'dotterel', 'camper', 'battles', 'preatomic',
    'aculeate', 'delphinite', 'mandatary', 'camacho', 'flounder', 'dramshop',
    'codens', 'champagnes', 'labyrinth', 'microlitic', 'amylan', 'bobadil',
    'relaxing', 'fagottino', 'heterosexual', 'westwards', 'insert', 'silly',
    'critter', 'codfish', 'imperforates', 'cherly', 'comically', 'trigonous',
    'atavistic', 'tires', 'tournefortian', 'papain', 'corina', 'semihistorical',
    'ericsson', 'groggy', 'coelacanthoid', 'overspeculation', 'impious', 'wolf',
    'infirmness', 'ceruleum', 'gizzard', 'hepatolith', 'schnecken', 'sorest',
    'phlegmier', 'quoll', 'arctoidean', 'subarcuation', 'indexical', 'steric',
    'salmon', 'annoyed', 'befouled', 'debus', 'spent', 'boutade', 'tracing',
    'haired', 'ergal', 'naphthoxide', 'brindlish', 'bongo', 'charlotte',
    'benzein', 'flowerlessness', 'molybdite', 'redictating', 'bilbo',
    'enshroud', 'virgal', 'doglike', 'tripe', 'woundless', 'powered',
    'aromatised', 'merchants', 'anhedonia', 'proforma', 'censitaire',
    'centrefolds', 'chorai', 'gloms', 'frazzled', 'blackman', 'lariated',
    'bobcat', 'delat', 'barbi', 'sedimentary', 'malvasia', 'confection',
    'solver', 'nyctophobia', 'dolmen', 'angara', 'overfallen', 'neuratrophic',
    'hadron', 'crossways', 'christia', 'dissave', 'crumpler', 'religionists',
    'aspic', 'bourgeois', 'elephant', 'blacklegging', 'antonin', 'shipwrightry',
    'devenustate', 'arterial', 'decertation', 'agalloch', 'diallings', 'batch',
    'guernsey', 'peacocked', 'towers', 'carapus', 'liftoff', 'alleviated',
    'coaly', 'sarcophilous', 'predelinquent', 'rat', 'bandmaster', 'cotte',
    'bechern', 'beaver', 'fribbled', 'overincline', 'eagle', 'beppie',
    'overabusiveness', 'climbed', 'aggregations', 'saltire', 'whigling',
    'repentingly', 'apparition', 'morbility', 'abusers', 'vegan', 'hiddenmost',
    'removed', 'uninfluencing', 'cellmate', 'eyelashes', 'noncircularly',
    'criticism', 'shortcut', 'curlew', 'cocker', 'rockaby', 'occurse',
    'ancient', 'undersomething', 'rafflesia', 'seismographic', 'pepsinate',
    'defined', 'charil', 'anabel', 'cordinar', 'antiquarian', 'bottlefeed',
    'gar', 'antre', 'multibreak', 'alanson', 'caslon', 'burkey', 'callery',
    'exotic', 'answers', 'permocarboniferous', 'pilocystic', 'troutflower',
    'contrabandista', 'polychromate', 'antelope', 'humidified', 'tawer',
    'barracuda', 'collaborationists', 'enderle', 'fabulously', 'lawing',
    'papal', 'arbel', 'alair', 'mulctary', 'double', 'thoracic', 'breakup',
    'siums', 'landshard', 'allida', 'anoop', 'heidi', 'unstridently',
    'sarcoplastic', 'roorbach', 'aborticide', 'processor', 'antisun',
    'briolettes', 'alveolarly', 'zebu', 'milliweber', 'abject', 'citronella',
    'incinerating', 'ambition', 'approachable', 'casuariidae', 'anthelia',
    'guidon', 'bronny', 'abody', 'predeciding', 'ditto', 'demandative',
    'articulate', 'australi', 'arctalian', 'bellhop', 'hierogamy', 'counts',
    'catfight', 'elding', 'screechbird', 'antdom', 'perceant', 'quokka',
    'debilitate', 'blacktop', 'aliens', 'recompass', 'downbeat', 'warve',
    'horotelic', 'entredeux', 'narcotization', 'planarian', 'massa',
    'trophospongium', 'envelop', 'booby', 'belee', 'chirre', 'nonstereotyped',
    'revetoed', 'soundless', 'motophone', 'bigots', 'dhole', 'silverwood',
    'econometrics', 'arylate', 'clarin', 'engravers', 'possum', 'mocha',
    'cardiff', 'ditty', 'bombings', 'scalded', 'comart', 'cabalist',
    'chocolatey', 'burker', 'blackroot', 'brockman', 'aurite', 'antinormal',
    'hemicentrum', 'cyros', 'snakemouths', 'antically', 'pteridium', 'dollop',
    'draughtsman', 'christel', 'gulley', 'babyface', 'spieler', 'palindrome',
    'twitty', 'dawns', 'sulphitic', 'lunchroom', 'shou', 'hermele',
    'inadventurous', 'butcheress', 'aissaoua', 'archplagiary', 'bedroom',
    'goldfish', 'tinkle', 'memoir', 'quadridigitate', 'boarding', 'piques',
    'sectuary', 'disquantity', 'undeemed', 'ambiguous', 'discording', 'badger',
    'micromastictora', 'arrhythmia', 'monikers', 'horse', 'broch',
    'anaesthetic', 'lashorn', 'dhava', 'taxidermist', 'ambivalent', 'satsumas',
    'foraneous', 'antifowl', 'medicodental', 'dominate', 'edsel', 'carlett',
    'panther', 'dupable', 'bijou', 'caxton', 'dragonade', 'acephalous',
    'bellman', 'cephalins', 'swinburnesque', 'edifier', 'chalon', 'discovert',
    'clone', 'audrie', 'bugler', 'glycerol', 'arlyn', 'asperates', 'downless',
    'sectored', 'pseudosquamate', 'benthic', 'bethel', 'bopeep', 'capomo',
    'simmer', 'factice', 'unaltering', 'veratroyl', 'angelika', 'michelangelo',
    'crepeau', 'succoring', 'discus', 'beggarman', 'whoever', 'eckler',
    'shaman', 'boneless', 'speisscobalt', 'corsair', 'constitutions', 'dendral',
    'acolapissa', 'rolfers', 'airflow', 'inaccessibility', 'engle',
    'reflection', 'crawthumper', 'sensated', 'durango', 'reabandoned',
    'middlesplitter', 'amit', 'belowdecks', 'diazide', 'craft', 'boats',
    'simars', 'moth', 'mouse', 'modestly', 'triaene', 'samlet',
    'europeanization', 'alway', 'stridingly', 'unzips', 'bleaching', 'carlean',
    'dewdrop', 'ruff', 'hoers', 'capuche', 'rec', 'watercourses', 'gouger',
    'abilities', 'postfire', 'ectozoans', 'trs', 'forecastlehead', 'biabo',
    'astrophil', 'caviling', 'drover', 'daphna', 'antitrismus', 'deaved',
    'behaviour', 'manche', 'bunraku', 'flittiness', 'hypergeometry',
    'disorient', 'chatelaine', 'arghan', 'lageniform', 'dismember', 'obsoletes',
    'beverlee', 'cauliflower', 'hubcaps', 'cineraria', 'interhabitation',
    'pregustic', 'eyetooth', 'distances', 'semiliquidity', 'crumble', 'manatee',
    'enriquet', 'defiant', 'adriena', 'catfish', 'gloamings', 'cosmopolitanize',
    'gasped', 'unsacrificial', 'wrinkle', 'unindicatively', 'bromhydric',
    'anstett', 'retepora', 'incombustibility', 'repressionary', 'annoyer',
    'bibiri', 'dunsmore', 'legmen', 'rhoding', 'starers', 'deuteron',
    'sexiness', 'completer', 'demijohn', 'anesthetize', 'centered',
    'antebellum', 'oxysalts', 'subsextuple', 'andalusite', 'californicus',
    'conservatives', 'cherished', 'unshackled', 'atwood', 'haler',
    'amphibological', 'incisors', 'unobstructedness', 'tithing',
    'decadactylous', 'street', 'filmer', 'barbara', 'deutzia', 'stowdown',
    'holoptic', 'bashed', 'acclimatize', 'tonights', 'brack', 'banshie',
    'glassware', 'oversured', 'assuming', 'boosters', 'kehillah', 'disturber',
    'harmonious', 'recharger', 'leases', 'chrisman', 'creeps', 'exacta',
    'tribromophenol', 'canossa', 'rivals', 'sapota', 'storminess', 'paellas',
    'moose', 'bronze', 'disembodied', 'bumpy', 'darkies', 'internetwork',
    'biddings', 'ovenful', 'bowers', 'fahey', 'baht', 'cinque', 'notturni',
    'belion', 'aphotic', 'struthionine', 'longshoremen', 'craniospinal',
    'unimodal', 'pigeoner', 'rhoda', 'lingering', 'chinho', 'bottleman',
    'stirrup', 'cardecu', 'runaround', 'acinar', 'caridean', 'reobtains',
    'decreers', 'sciences', 'cardamom', 'caribous', 'annemari', 'mistimed',
    'decrowning', 'femoropopliteal', 'havens', 'chaya', 'subalgebraical',
    'anything', 'eikon', 'dryas', 'modest', 'nontechnically', 'veddoid',
    'stinkbug', 'evaporative', 'fallacy', 'cohesion', 'avenue', 'stereology',
    'calctufa', 'blackfeet', 'cockeyed', 'offside', 'flocoon', 'alist',
    'ecocide', 'espriella', 'breaststroker', 'arrivisme', 'embark', 'exclude',
    'bider', 'thrillingness', 'delly', 'emilee', 'blackseed', 'dentin',
    'totemists', 'ventages', 'cuirassier', 'disyntheme', 'thalamolenticular',
    'xanthindaba', 'eminence', 'defect', 'reinfecting', 'marcello', 'cosimo',
    'clevie', 'cherlyn', 'buggyman', 'balmy', 'neuropathical', 'feels',
    'polled', 'cannibal', 'bastioned', 'abrus', 'sigmodont', 'irradiated',
    'underlain', 'coner', 'seugh', 'nonvicarious', 'diffraction', 'unpinched',
    'enhancer', 'dimitra', 'awesome', 'damil', 'intracutaneously', 'inviscid',
    'glome', 'chape', 'tepid', 'amalie', 'detin', 'tonsured', 'kickstands',
    'haole', 'dungs', 'woesome', 'camden', 'fowl', 'homologoumena', 'dinkey',
    'taen', 'sexillion', 'resignful', 'ascertainability', 'mariachi',
    'dyspepsia', 'ooecium', 'alike', 'pinta', 'inflates', 'brocks', 'castling',
    'doolittle', 'apurba', 'chien', 'pygofer', 'bourlet', 'burian',
    'ramentiferous', 'tafia', 'seal', 'borak', 'addis', 'yappiness',
    'detonations', 'wangler', 'prosecutor', 'apina', 'awest', 'imperatorially',
    'hippopotamus', 'kalimbas', 'alive', 'schizophrenic', 'runnion',
    'calculous', 'normoblastic', 'parietals', 'ayatollah', 'peponidas',
    'planted', 'coregonus', 'jurisprudentially', 'cercopithecus', 'beylic',
    'abundant', 'divide', 'shaly', 'wongsky', 'predischarge', 'dendrobatinae',
    'autocall', 'calabrese', 'capriole', 'playland', 'irremissibleness',
    'mowstead', 'buzzsaw', 'unsanitation', 'adoree', 'pentachenium',
    'histotrophic', 'amarelle', 'perivenous', 'thereinbefore', 'antelation',
    'tuatera', 'sparerib', 'arora', 'scope', 'tylostylar', 'filagree', 'cologs',
    'danielak', 'guineapig', 'tarantas', 'coral', 'parrot', 'brahminic',
    'bolden', 'curvilinear', 'improbable', 'psychodynamic', 'agathodaemon',
    'dermis', 'crude', 'cantalas', 'disadventure', 'peteca', 'quail',
    'intendancies', 'nonflexibleness', 'caved', 'dollishly', 'sistering',
    'bulimia', 'nasociliary', 'fortuneteller', 'deipnosophism', 'kindle',
    'banaba', 'clethra', 'dispatched', 'procline', 'sylvan', 'tapir',
    'deipnophobia', 'entach', 'bobwhite', 'wrasse', 'pademelon', 'requestor',
    'metatarsi', 'decimate', 'photon', 'aplomb', 'curate', 'alluvium',
    'clients', 'bogland', 'subantarctic', 'scurfiness', 'eccentrics',
    'mesosphere', 'valetudinariness', 'argonaut', 'unexplainableness', 'amick',
    'antagonizing', 'proletarianised', 'votiveness', 'rebukable',
    'undiscernibly', 'clonus', 'documentary', 'cormorant', 'affirmation',
    'forgeability', 'extraneous', 'alaunian', 'alsaleh', 'delroy', 'anabasis',
    'incarnate', 'upseek', 'schoolyard', 'derivedness', 'triphammer', 'cembalo',
    'antiprime', 'misleadingly', 'couturier', 'protragedy', 'minning',
    'cantaloupes', 'querimans', 'brusque', 'distad', 'desiderative',
    'thyroxine', 'ardea', 'diagnose', 'uniaxally', 'walies', 'alluring',
    'basin', 'misnomer', 'geometry', 'demimark', 'delightingly', 'waggle',
    'sparkplugging', 'adminstration', 'redout', 'bianka', 'brainwork',
    'blandishingly', 'decumani', 'creak', 'grasshopper', 'ceruse', 'regga',
    'skinkers', 'spurnwater', 'warthogs', 'sines', 'slithery', 'vomer',
    'electroretinography', 'bloodlessly', 'lymph', 'classical', 'mule',
    'visionariness', 'lapwing', 'aloof', 'extraorbitally', 'cherokee',
    'chinook', 'stengah', 'levotartaric', 'brogan', 'endosteum', 'hipmi',
    'bernadin', 'customer', 'elevatory', 'carious', 'dormouse', 'cobhead',
    'detail', 'bogert', 'spermophile', 'dryermen', 'northings', 'embrothelled',
    'overshadow', 'faliscan', 'malleablize', 'bauch', 'jocosities', 'milliard',
    'deselecting', 'coinheres', 'please', 'veining', 'subturbary',
    'unpresuming', 'unperfidiousness', 'ontography', 'ajourise', 'angry',
    'perturbation', 'senna', 'coffinmaker', 'canuck', 'metachromatic', 'jebus',
    'arney', 'ardelia', 'backout', 'alister', 'namelessly', 'algal',
    'fumarases', 'aichmophobia', 'another', 'direction', 'reshoulder',
    'hastings', 'bluely', 'cyprus', 'chenault', 'cayuga', 'caroli', 'basile',
    'bactrian', 'suppleness', 'subtrahends', 'browsers', 'claimed', 'nibble',
    'girlies', 'mesovaria', 'invalidish', 'befoam', 'beland', 'caiman', 'entad',
    'quarts', 'polybrid', 'scalper', 'iatraliptics', 'drawlingly', 'devoir',
    'laureate', 'spectators', 'entomb', 'knifelike', 'misdirects', 'discussant',
    'mortarware', 'biune', 'missilery', 'hyperpersonal', 'abhorrent',
    'carnations', 'famishment', 'processal', 'sourbellies', 'uniserial',
    'cresoxide', 'derelict', 'rhamnohexite', 'concretization', 'rhamnus',
    'egality', 'burger', 'mothball', 'bureaus', 'goose', 'lemming', 'ashlin',
    'annihilates', 'repercussively', 'aspire', 'crinoline', 'briolette',
    'gabgab', 'yatigan', 'mose', 'trichotomize', 'cadaveric',
    'interzygapophysial', 'throuch', 'influenzic', 'cordilleran',
    'sclerenchyme', 'electrodesiccation', 'prissy', 'lanson', 'chamade',
    'woofs', 'financiers', 'paves', 'subgalea', 'exceedingly', 'protrusile',
    'supercommendation', 'baldest', 'elute', 'caracal', 'foothill', 'separated',
    'epicontinental', 'aptly', 'emulating', 'ultrasonic', 'breakless',
    'fastuousness', 'banderma', 'fragmentized', 'rauwolfia', 'bobbery',
    'mowrah', 'tailcoat', 'gooses', 'spiring', 'eclair', 'appetite', 'tzarina',
    'chroococcaceous', 'chegre', 'prodissolution', 'chaute', 'apropos',
    'oscillancy', 'artur', 'oilfish', 'cogitate', 'vodkas', 'toughie',
    'gonenesses', 'inconsultable', 'calfret', 'henna', 'dimity', 'camata',
    'heteroploidy', 'hubristic', 'rotted', 'revulsion', 'tubenose', 'malik',
    'biovular', 'bachelor', 'schlock', 'bullocks', 'dayman', 'coast', 'dotes',
    'peculiarise', 'blizz', 'slaters', 'organismal', 'awatch', 'danny', 'dawne',
    'proclaimed', 'snowdrops', 'eeeeee', 'clairvoyants', 'devotes', 'dervish',
    'megaword', 'bemar', 'betumbled', 'chignon', 'umbrellabird', 'spiketail',
    'ordanchite', 'anita', 'panicked', 'dylan', 'balcony', 'zoner', 'ulcuscle',
    'humanitarianism', 'snorkeling', 'babbage', 'filamentiferous', 'bleach',
    'bagdad', 'orache', 'punproof', 'adoptable', 'anthonin', 'spearing',
    'trust', 'mosso', 'deprive', 'postimpressionist', 'tuke', 'cocain',
    'unfavourably', 'bihai', 'avigdor', 'falls', 'restatement', 'molluscans',
    'beelol', 'schnaps', 'chander', 'unproperness', 'slavonian', 'ilicaceae',
    'bowered', 'appointment', 'circulate', 'zoophobia', 'flycatcher',
    'renascible', 'armour', 'directory', 'dives', 'cameraman', 'alcyone',
    'annonce', 'mediatorial', 'rhiptoglossa', 'aggregat', 'monstrosities',
    'duress', 'eastland', 'coils', 'araks', 'archimedes', 'cronet', 'bucketman',
    'lion', 'plimsol', 'boohoo', 'scions', 'plectridium', 'trout', 'amphigory',
    'bidens', 'commanding', 'interleaver', 'estrange', 'lizard', 'chiropractor',
    'bombyx', 'panga', 'mellic', 'antirepublican', 'noblify', 'ayukawa',
    'available', 'cambridge', 'refrustrated', 'cringingly', 'catacombs',
    'loris', 'earlock', 'euonymus', 'bloch', 'cryptomere', 'drooping',
    'antiexpressionistic', 'coumara', 'winters', 'stonelayer',
    'unsuperstitiousness', 'daymare', 'nonblooming', 'cholones', 'merrily',
    'prohibitionary', 'rajarshi', 'swimy', 'meerkat', 'wedgeable', 'hadrons',
    'husbandfield', 'choctaw', 'amazons', 'amaranthine', 'reservery',
    'phrenetically', 'affies', 'mudrooms', 'betaking', 'decagon', 'sedated',
    'booking', 'chuddar', 'blunter', 'demibrassart', 'prorebate', 'unsquirming',
    'assays', 'ballots', 'delirious', 'fulgurous', 'shortcake', 'seawan',
    'altitudes', 'acers', 'unroomy', 'chumps', 'cyrenaic', 'pisiform',
    'cerulean', 'myelopathy', 'dorsocaudad', 'sideburns', 'coleridge', 'aural',
    'setiparous', 'aitch', 'sales', 'anxious', 'omophagous', 'conestoga',
    'fermentitious', 'sgraffito', 'amorim', 'tepidity', 'gothish', 'skere',
    'sillago', 'unfickle', 'upbrighten', 'akinesia', 'fidejussion',
    'depravities', 'bifront', 'costumes', 'brigandine', 'chinchilla',
    'hepatotoxic', 'rotundity', 'clairce', 'bromid', 'inducting', 'blackberry',
    'jazzing', 'polarographically', 'compassionless', 'albatross', 'aywie',
    'macrobiotus', 'sphenoidal', 'narsinga', 'amnesia', 'vulnerable',
    'developed', 'shapiest', 'pamperers', 'bizen', 'northeners', 'shmaltzier',
    'outmantle', 'binette', 'straths', 'console', 'elanor', 'apathies',
    'tautousian', 'bengalic', 'tariff', 'alans', 'unreportedly', 'quetzal',
    'edlin', 'bluecollar', 'breton', 'celadon', 'datos', 'hilum', 'sunshiny',
    'swallow', 'quinamine', 'cassandra', 'strumatic', 'stationmaster', 'didus',
    'lithopone', 'proseman', 'believer', 'cruth', 'abyssinian', 'disenclose',
    'mixers', 'gull', 'dodecapartite', 'anglist', 'fantasize', 'plotter',
    'bovid', 'enzym', 'bitterbush', 'discoverer', 'african', 'unrowdy', 'anent',
    'apotropaion', 'pangamous', 'stachydrin', 'landings', 'drever', 'mongoose',
    'acree', 'danie', 'pleurotoma', 'charlene', 'leucoryx', 'chrysotherapy',
    'analgesist', 'beresfor', 'euda', 'avocet', 'lionfish', 'strongboxes',
    'aiding', 'arachnoid', 'scurry', 'unspecific', 'gulonic', 'starship',
    'egalites', 'damager', 'salaciousness', 'stagonospora', 'snop',
    'overclamor', 'trillet', 'kapp', 'redundancies', 'cocobolos', 'augurs',
    'cobra', 'disfavourable', 'wildebeest', 'aglaos', 'alert', 'novcic',
    'unfinable', 'uninspired', 'sphericotetrahedral', 'vituperatory',
    'strepsiceros', 'balaban', 'dreyfuss', 'squamipennes', 'samaras', 'bobby',
    'tooroo', 'scatt', 'ditone', 'goshawk', 'sawing', 'libra', 'zorse',
    'deflatable', 'becca', 'reflowers', 'adventure', 'abatis', 'cappadine',
    'benton', 'therapy', 'unpolemically', 'bandits', 'betassel', 'echinus',
    'unfeasibleness', 'angelship', 'deathy', 'paradise', 'hydrome', 'scouth',
    'trabecularism', 'absconsa', 'ferule', 'salads', 'industry', 'aperies',
    'acetract', 'bigman', 'havanese', 'disappearance', 'aboveground',
    'eightsmen', 'coquelicot', 'outbetter', 'dynatrons', 'tromometric',
    'biostatistic', 'palmiped', 'gobio', 'anvil', 'sprit', 'neanderthal',
    'afterfuture', 'bouse', 'peristylium', 'pooty', 'teletypewriting', 'osmols',
    'bride', 'undenotative', 'reemits', 'caterina', 'aurore', 'dingar', 'eller',
    'nainsooks', 'vibrative', 'antisociality', 'equvalent', 'abstinent',
    'heterotricha', 'overstridentness', 'cookeys', 'disazo', 'consciousness',
    'crassula', 'corkey', 'behalf', 'ceriel', 'requisitely', 'haspspecs',
    'projacient', 'nonmannered', 'body', 'chitter', 'tropicbird', 'chrismary',
    'privater', 'dominium', 'pastorale', 'cecon', 'delaminate', 'accidental',
    'synascidian', 'balate', 'progenitorship', 'aardvark', 'volleyed', 'dorter',
    'commander', 'trochozoa', 'shivarees', 'didine', 'amusing', 'cherries',
    'polyrhythm', 'schematic', 'reindeer', 'transchannel', 'redeployed',
    'apodeictical', 'duckers', 'jargoons', 'webworms', 'leghorn',
    'mesoblastemic', 'claustrum', 'drakes', 'dweller', 'woodenweary',
    'criminologist', 'cyanizing', 'diplopod', 'eruditeness', 'churchill',
    'disconsolate', 'boyscout', 'concrete', 'contineu', 'gustavus',
    'contradiction', 'eliminator', 'trucker', 'drainer', 'botheration',
    'deckchair', 'stupid', 'billows', 'expatriate', 'adaw', 'ripost', 'scorer',
    'pectinogen', 'echovirus', 'dustman', 'bateman', 'bewitching', 'esclavage',
    'countenancing', 'carding', 'delawn', 'asbest', 'misenters', 'resectional',
    'ammar', 'rebend', 'conscience', 'human', 'celesta', 'intercom', 'heuchera',
    'deutomalar', 'overdiscount', 'kinkajou', 'adamczyk', 'immigrating',
    'convair', 'curcumas', 'donohue', 'kenticism', 'blabber', 'kentrogon',
    'banish', 'aberrant', 'revivals', 'rugbeian', 'roccelline',
    'reprehensibility', 'haters', 'contemplative', 'outwept', 'bizonia',
    'decubitus', 'segued', 'absit', 'crinoid', 'albian', 'neuter', 'sensatory',
    'darkens', 'oenin', 'protocoled', 'mopeier', 'thousands', 'unpostulated',
    'akbash', 'reasonable', 'acute', 'ostraca', 'jounces', 'uppercutted',
    'unpanged', 'selachian', 'bonehead', 'coolest', 'hamline', 'longhair',
    'twattles', 'nonfeverishly', 'whiffled', 'huddock', 'aluminum', 'larcenies',
    'battling', 'cushily', 'ostsises', 'puddinglike', 'birken', 'carful',
    'tinct', 'aciduria', 'sylvin', 'nonoccurrence', 'vigors', 'altin',
    'gritstone', 'atman', 'anagoges', 'cancerated', 'recreations', 'armadillo',
    'cockroach', 'centrist', 'amygdalotome', 'natriuretic', 'cadging',
    'wiggeries', 'prefinanced', 'evenfalls', 'addicted', 'dorser',
    'gravelliness', 'admonisher', 'unmoderated', 'dextro', 'bygones', 'alaric',
    'indignity', 'maile', 'selvas', 'dacian', 'peacemaker', 'bevatrons',
    'triplopia', 'ungladness', 'stenophragma', 'arlin', 'flabbiest', 'bemis',
    'jargonel', 'glomerate', 'combo', 'choices', 'colorate', 'culebra',
    'dauties', 'sawbucks', 'viking', 'tenant', 'clamorous', 'nozi', 'deloris',
    'oversowed', 'ryegrasses', 'ruewort', 'shrubberies', 'canamo',
    'salutatious', 'airplay', 'ananda', 'squirting', 'dessa', 'prunitrin',
    'donal', 'cercle', 'consolatrix', 'aglycons', 'sizzles', 'cooling', 'sucks',
    'bloodstains', 'debater', 'granddada', 'gruesome', 'evangelian',
    'touchable', 'ceramics', 'thermostat', 'phrenosinic', 'prelacy',
    'restipulatory', 'canopus', 'harrier', 'macrophyllous', 'dauphine',
    'acquisita', 'attune', 'cautions', 'iguana', 'dustuck', 'jungles',
    'mindsets', 'unthumped', 'decalage', 'paleornithologist', 'kazatske',
    'mastiff', 'sciomachiology', 'ceara', 'dissolubleness', 'peacock',
    'exophasic', 'erminia', 'abucco', 'cutlass', 'giggled', 'schoolbookish',
    'cuerda', 'deuterogenesis', 'unliberally', 'adjoining', 'balmoral',
    'fenbank', 'shuttlelike', 'artiller', 'samba', 'ental', 'palmetto',
    'forepeak', 'desistance', 'vibrio', 'hautbois', 'santalol', 'embryony',
    'unmanageably', 'vertep', 'carnell', 'sewings', 'davey', 'seahorse',
    'exophoria', 'cinerins', 'ram', 'creche', 'sidebones', 'adenitis', 'serval',
    'hydronegative', 'unwailing', 'bagging', 'arcanist', 'findings', 'atune',
    'scarabaeus', 'stele', 'laylight', 'cupper', 'bealle', 'englishmen',
    'flatland', 'award', 'insulators', 'hotpot', 'cambre', 'bantay',
    'uncovenant', 'dijian', 'crescentia', 'baktun', 'owl', 'probonding',
    'circle', 'actinon', 'overhumanizing', 'animations', 'erwin', 'argiope',
    'controllers', 'boran', 'emblem', 'apologies', 'chameleon', 'suez',
    'sweatband', 'floods', 'cabinda', 'muumuu', 'abnormal', 'teemless',
    'narwhal', 'furiosity', 'amphibia', 'levelheaded', 'dirtbird', 'corker',
    'didie', 'deodate', 'dunlin', 'accurate', 'kerning', 'hippidium', 'deckers',
    'bragget', 'semicotyle', 'cyanic', 'compulsed', 'consolato', 'buccan',
    'swingaround', 'serialism', 'benzoglycolic', 'coracosteon', 'phies',
    'unreluctantly', 'endeavours', 'abolished', 'rhizobium', 'staminigerous',
    'veligers', 'abrar', 'concussion', 'subglobularly', 'elasmosaur',
    'cantharis', 'mildish', 'blubber', 'atlas', 'scorner', 'clocks',
    'esterification', 'recycled', 'tirrivees', 'angelfish', 'sokols', 'd-day',
    'augends', 'shopkeeperess', 'isobutylene', 'completers', 'saleps',
    'aphelandra', 'nasi', 'checksumming', 'colorant', 'lehuas', 'aluminosis',
    'ditch', 'flamingos', 'candida', 'unfatuitously', 'costello', 'moors',
    'bluegums', 'pupillonian', 'minima', 'bondon', 'aboriginal', 'prisons',
    'wimple', 'unlawyerlike', 'banya', 'codebreaker', 'moping', 'lifts',
    'citrons', 'verbiages', 'prats', 'colder', 'canille', 'apartness', 'roving',
    'endable', 'cardiophrenia', 'cephalotripsy', 'minimi', 'laceration',
    'costectomy', 'schuss', 'resubmitted', 'pyrogenicity', 'brose', 'fairy',
    'huckaback', 'aiwan', 'tommed', 'reamalgamated', 'fanes', 'admissible',
    'cassady', 'christea', 'ashton', 'overtedious', 'seersucker', 'pongidae',
    'sanatorium', 'granulator', 'catgut', 'jinkle', 'peculiarizing', 'desdemon',
    'meteorology', 'chaperno', 'cuttail', 'confused', 'drive', 'labiduridae',
    'bronco', 'sequentializing', 'guidage', 'castaways', 'chicest', 'queenweed',
    'chlorozincate', 'sledged', 'croppy', 'elephantiasis', 'herbosity',
    'engrave', 'caddle', 'abundantia', 'subcostae', 'celloid', 'buccina',
    'enflagellation', 'coccids', 'catharizing', 'ocelot', 'douping',
    'unsoporific', 'epistropheus', 'unmentionability', 'cherimoya', 'pekingese',
    'beatitudes', 'precogitation', 'charline', 'almadia', 'sensorium', 'ripa',
    'cusick', 'creaks', 'esurience', 'mousse', 'corders', 'brydges', 'benthos',
    'snowdrop', 'saola', 'semidiaphanously', 'croci', 'ruttily', 'pulmometer',
    'benni', 'training', 'chauffeur', 'gorgoniaceous', 'chunmei', 'listers',
    'colourblind', 'ambitious', 'pensione', 'caboodle', 'enteron',
    'extemporaneity', 'almida', 'admirable', 'cilice', 'dhurrie', 'alligators',
    'cheryl', 'yak', 'limbate', 'wivern', 'postscapular', 'zimbi', 'cigua',
    'pediatric', 'collard', 'misdeemed', 'campo', 'britt', 'petal', 'bahama',
    'decolor', 'kilts', 'boisset', 'weedlike', 'semiorb', 'fagan', 'changeover',
    'mankilling', 'freemen', 'awide', 'jujube', 'bloodhound', 'elastica',
    'aspersion', 'chiefs', 'slammer', 'brocade', 'pika', 'haemoflagellate',
    'takeout', 'eardrum', 'agamic', 'cunard', 'stenocephaly', 'cleistogamously',
    'baklavas', 'subspace', 'despiteously', 'cadwal', 'foreordaining',
    'forerank', 'ignatian', 'arpita', 'afret', 'bulbous', 'ennead', 'pedicab',
    'application', 'chordate', 'bluefish', 'imbrices', 'woodlouse',
    'countermandable', 'content', 'skyre', 'scrounge', 'sawer', 'securableness',
    'poephaga', 'ragger', 'blowbacks', 'armenoid', 'scythe', 'coir', 'leese',
    'basnet', 'cementation', 'anatolic', 'profiler', 'auditoria', 'footcandle',
    'wrath', 'centrosome', 'myoporum', 'argus', 'fiducial', 'spasmodically',
    'burley', 'contraptious', 'crinoids', 'pirogue', 'claval', 'calefacient',
    'appraisal', 'ebbman', 'delight', 'adansonia', 'downturn', 'chiseler',
    'cascarilla', 'rallier', 'evened', 'catawampus', 'anaryan', 'bijan',
    'elfreda', 'erythrocyte', 'cocooned', 'hucksterage', 'canadian', 'corvo',
    'chicomecoatl', 'anasazi', 'unsobering', 'sighted', 'coffin', 'afterlife',
    'dulcity', 'charmless', 'limns', 'assailants', 'transplantar', 'science',
    'rickstand', 'elephas', 'impassibly', 'unbiblical', 'barb', 'mullite',
    'exegesis', 'attractive', 'ergotic', 'doused', 'dessain', 'secret',
    'baalath', 'sirens', 'alidia', 'carpetbag', 'byproducts', 'explains',
    'zaffer', 'penning', 'unbetrothed', 'splays', 'diets', 'preacquisition',
    'babuina', 'quelea', 'conceder', 'popularise', 'netchilik', 'smarmy',
    'liger', 'magpie', 'atlanta', 'crocky', 'preexamines', 'gamester', 'seiner',
    'phenylic', 'erena', 'scrunch', 'penicilliform', 'nusakan',
    'etherealization', 'dimetry', 'irrefragability', 'dog', 'apron', 'nebula',
    'cloherty', 'umiaq', 'costarred', 'eyebrow', 'cutesy', 'shamus',
    'fiddlestick', 'zapateo', 'enamels', 'puffs', 'pointer', 'palmira',
    'snowmobile', 'effaced', 'hardyhead', 'together', 'necking', 'cingulate',
    'coggly', 'epurate', 'quassiin', 'immethodicalness', 'regroove', 'dryad',
    'filemaker', 'magenta', 'rhyolite', 'correy', 'paterero', 'arpen', 'carted',
    'scalp', 'picoline', 'chewer', 'bison', 'dryopians', 'nasiei', 'sextur',
    'loudmouthed', 'jewish', 'unhelved', 'berkowitz', 'exceptionalness',
    'gaspy', 'medical', 'stedhorses', 'chandra', 'boother', 'databank',
    'bitumen', 'hemerobius', 'decafid', 'hangfire', 'psychodispositional',
    'pleurotyphoid', 'nonadjacent', 'branchful', 'amazing', 'aviation',
    'curupira', 'dipak', 'protegulum', 'cocoa', 'arrowy', 'recleansing',
    'tiffany', 'brunel', 'zareebas', 'chump', 'efficacies', 'punkwood', 'snips',
    'censored', 'apium', 'bernelle', 'jollier', 'chitarrone', 'toelike',
    'sorts', 'bedlamps', 'glucose', 'rotundness', 'criminol', 'albizzia',
    'tenons', 'diving', 'dulosis', 'polyodontia', 'boons', 'totoro', 'addendum',
    'abiding', 'nontarred', 'disappear', 'consultary', 'abdel', 'schrik',
    'ellie', 'bikers', 'sophies', 'unpaste', 'cottontail', 'chital', 'reefer',
    'saucerman', 'simoom', 'stowps', 'favela', 'antipodes', 'chazans',
    'alboranite', 'interpretive', 'slatemaker', 'versatec', 'viper',
    'concentric', 'cicatrix', 'belay', 'harborers', 'pastilled', 'cottonmouth',
    'skunk', 'bouncy', 'culet', 'asians', 'ladybird', 'entails', 'simpleminded',
    'skewbacked', 'baton', 'claudius', 'hematite', 'asbestosis', 'aesthetic',
    'areito', 'bhutia', 'except', 'unaccountably', 'rachidial', 'lambs',
    'ambushes', 'lithoclase', 'borgh', 'bilayer', 'illegible', 'guppy',
    'protologist', 'russet', 'winnard', 'cajaput', 'ducking', 'experimentally',
    'telephoto', 'buxom', 'iridescent', 'dondaine', 'sulcate', 'erroneously',
    'became', 'dehydration', 'starlighted', 'peccable', 'indris', 'combinator',
    'hoc', 'gas', 'desires', 'saddlers', 'baconize', 'replenished', 'abandoned',
    'bleeker', 'workaholics', 'basenji', 'dickford', 'euphonetic', 'newt',
    'ambar', 'drumlin', 'misogamic', 'apatornis', 'fidelia', 'cypselous',
    'cadmium', 'peroxid', 'obduce', 'acclimatise', 'socked', 'monadiform',
    'claimer', 'nonya', 'turnbuckles', 'baboonery', 'malpractice', 'retying',
    'uncertainties', 'lamebrain', 'nobodies', 'estherian', 'bolete',
    'introgression', 'snapberry', 'frigatebird', 'untightened', 'epeira',
    'pluguglies', 'bitumens', 'nephology', 'anilidic', 'altruistic', 'catie',
    'chakras', 'scenarizing', 'adoptee', 'executed', 'croteau',
    'redissolubleness', 'elusions', 'aswan', 'ascanius', 'inkmaking',
    'omnivora', 'maidhoods', 'foreknowable', 'anthema', 'abounding',
    'chromatics', 'dryers', 'electrophone', 'bubales', 'toruloid', 'admedial',
    'orthodox', 'pairing', 'misdeals', 'chromotherapist', 'deuterostomata',
    'celsius', 'topos', 'demir', 'redips', 'pondering', 'cypress', 'gunkholed',
    'horseheads', 'carburant', 'lawless', 'unstaled', 'zillionaire',
    'damnation', 'turmeric', 'bhima', 'nonanarchic', 'exposition', 'enforces',
    'untamely', 'peatery', 'cimex', 'homeothermic', 'executant', 'outlet',
    'anaconda', 'dewdrops', 'architectural', 'attentional', 'croquette',
    'deermeat', 'roseola', 'browning', 'discolor', 'calumny', 'enterocoele',
    'cooper', 'batteries', 'sourish', 'himalayan', 'donatistical',
    'dispassioned', 'tipple', 'brags', 'tressed', 'bumpier', 'beckoning',
    'athletics', 'allthing', 'dyslogistic', 'jerries', 'poule', 'forgotten',
    'nodder', 'predecessors', 'folkmooter', 'affluent', 'overembroider',
    'mutine', 'colston', 'perfecto', 'tootle', 'graciousness', 'pilastrade',
    'defensor', 'stad', 'goalkeeping', 'stoop', 'sensationistic', 'ecospecific',
    'baited', 'algonquin', 'inthralled', 'electrotechnics', 'allard', 'corydon',
    'chine', 'tuatara', 'mutawalli', 'article', 'azoturias', 'nonsubject',
    'piperazine', 'cichlid', 'dalmatian', 'dumbs', 'decoupage', 'dogtag',
    'microtome', 'ascension', 'dunker', 'unrooted', 'fairless', 'adcox',
    'binits', 'electrobath', 'displayer', 'doina', 'stizolobium', 'cochin',
    'biplab', 'spider', 'conform', 'adjuster', 'budgerigar',
    'revolutionariness', 'outthrew', 'chrysops', 'coronet', 'underorseman',
    'barnacle', 'buckling', 'dustbox', 'agnomen', 'contg', 'fallibly',
    'dastardly', 'bourcier', 'alvaro', 'zoopathological', 'bloodletting',
    'deceive', 'sedater', 'phlomis', 'crystallose', 'trichogrammatidae',
    'crustacean', 'centimeter', 'berberine', 'fairish', 'oversshot',
    'obscenity', 'arithmogram', 'deckie', 'stounded', 'wingseed', 'byrnie',
    'palafitte', 'celsitude', 'jay', 'carless', 'abducing', 'backdoor',
    'castell', 'billiards', 'dreamlit', 'tattooage', 'bondholding', 'catherina',
    'throne', 'tiger', 'nonslipping', 'incunabulist', 'bowyer', 'fossorial',
    'scallywags', 'plasmoid', 'lacrosse', 'bucerotidae', 'brancher', 'clason',
    'reversible', 'evacuator', 'ithomiidae', 'watersoaked', 'heartbird',
    'beverly', 'nonobstetrically', 'sighless', 'wended', 'absurd', 'heth',
    'daimen', 'herbivore', 'trioxide', 'bramble', 'iodimetry', 'quinidin',
    'axiomatic', 'transistors', 'deek', 'belissa', 'cise', 'burgle',
    'apocynaceous', 'areach', 'gallican', 'mediums', 'poplars', 'index',
    'unaffectionate', 'diviner', 'champertor', 'messor', 'alyda', 'unrobing',
    'monogamous', 'insurgently', 'dosimeter', 'proteose', 'cabrio', 'benzie',
    'therblig', 'bobbye', 'biogen', 'bateau', 'deserving', 'caggy', 'outcheat',
    'lipomas', 'dramas', 'basker', 'einkorn', 'racon', 'scrimpy', 'heartbreak',
    'nonangling', 'atmospheric', 'chough', 'recoilers', 'detailer', 'plummet',
    'rhinoceros', 'alkanethiol', 'intralobar', 'nace', 'carbineer', 'carotid',
    'plexuses', 'euktolite', 'remarry', 'surahs', 'imbonity', 'colicky',
    'matutinary', 'megaloenteron', 'myiarchus', 'quantifiers', 'chihuahua',
    'desynonymization', 'chapfallen', 'displeasingness', 'vault', 'correct',
    'alpaca', 'exaestuate', 'squeal', 'denes', 'radioactivities',
    'competitioner', 'teenage', 'marsileaceae', 'fashionably', 'glandarious',
    'elysia', 'marijuanas', 'ethelyn', 'tasty', 'bender', 'resolutionist',
    'flighted', 'slewer', 'chukchi', 'camelhair', 'hookheal', 'haycart',
    'apoda', 'frog', 'teethache', 'obvention', 'chouser', 'ustilaginaceous',
    'bluestones', 'bulbilla', 'ashamed', 'disobligatory', 'bisquette',
    'cryptic', 'unbrotherliness', 'eel', 'esmond', 'briar', 'penciled',
    'delage', 'trainbearer', 'couchy', 'illuminati', 'expansible', 'brither',
    'excavating', 'acceptable', 'annum', 'windswept', 'militaristic',
    'sclerosing', 'mibound', 'nonfossiliferous', 'antical', 'travertine',
    'colias', 'juking', 'paucity', 'cerite', 'afterimage', 'libeler',
    'suprafoliaceous', 'bepimpling', 'perfusate', 'tironian', 'bootlessness',
    'sundering', 'yoks', 'uncircumvented', 'buyable', 'lobster', 'opacifying',
    'guineafowl', 'devera', 'raven', 'davidh', 'fluffs', 'pike', 'indulger',
    'islamitic', 'premunire', 'crista', 'spermatovum', 'ape', 'theist',
    'emmett', 'cowhand', 'exertion', 'smidgin', 'ravish', 'retort',
    'destructive', 'religion', 'interabang', 'corruption', 'riverish',
    'bashalick', 'batiks', 'earmark', 'sellouts', 'complier', 'unchoking',
    'billowy', 'amperage', 'coater', 'canescent', 'agonizing', 'crureus',
    'palmae', 'quartern', 'yammering', 'timbersome', 'aporia', 'elgar',
    'against', 'spancel', 'multibranchiate', 'infantly', 'videotape', 'coarse',
    'agreeable', 'scoot', 'carving', 'ribbons', 'arses', 'documentaries',
    'okapi', 'phonophoric', 'autographs', 'thrilling', 'pony', 'nesty', 'koala',
    'dogie', 'subadars', 'afloat', 'septs', 'enormously', 'nonimposition',
    'emory', 'unrecorded', 'devow', 'persuasibly', 'bencher', 'chalton',
    'unwhistled', 'skycap', 'hamartia', 'ruthlessness', 'waylay', 'scorpion',
    'headwaiter', 'parallelized', 'emond', 'dissonancies', 'polylith',
    'dartboard', 'fanner', 'originally', 'antsier', 'dotan', 'termite',
    'shivey', 'pinchback', 'arienzo', 'addiction', 'skilling', 'unfeminize',
    'dekko', 'compose', 'leopard', 'comma', 'padmasana', 'biggers', 'congruism',
    'singly', 'balinese', 'adenine', 'myriophyllite', 'donning', 'bedlamic',
    'cupholder', 'prechecked', 'unworshipful', 'despoiler', 'snobby',
    'facecloth', 'burrus', 'satirically', 'dispirited', 'diakinetic', 'lactim',
    'breena', 'scoop', 'conquered', 'pharm', 'seaweeds', 'connexions',
    'religiousness', 'cannikin', 'dovetailed', 'beaulieu', 'civility',
    'cantabile', 'protoderm', 'beaucoup', 'periangioma', 'migraine', 'asmear',
    'octachord', 'vino', 'tang', 'unstaffed', 'renograms', 'needlestone',
    'cortina', 'clarified', 'subinterval', 'astor', 'ringtailed', 'coconscious',
    'doree', 'hocus', 'preview', 'dissembles', 'unsmokeable', 'holk',
    'bolshevik', 'mandrill', 'imprimaturs', 'callorhynchidae', 'arnone',
    'capabler', 'cryptocrystalline', 'upload', 'edomitish', 'postbrachial',
    'bedtime', 'levering', 'apocalyptic', 'alveolate', 'caffeina', 'drseuss',
    'trytophan', 'rook', 'charmian', 'azuma', 'estes', 'verisimilitude',
    'macrophage', 'dearaujo', 'evzone', 'unshunned', 'undog', 'centipede',
    'shares', 'bethlehem', 'eleonorite', 'syphered', 'intersprinkled',
    'crozier', 'erykah', 'remeant', 'reinvent', 'scheme', 'sulphine',
    'ridottos', 'cyrtidae', 'overshined', 'nonincriminating', 'idylls',
    'childe', 'weatherologist', 'countercoupe', 'subantichrist', 'bazooka',
    'pentasulphide', 'walspere', 'consolable', 'pooled', 'corporates',
    'anoraks', 'occlusions', 'faultlessly', 'summational', 'burmese',
    'bodymaking', 'cervid', 'nympholept', 'dacryoadenitis', 'heteroclinous',
    'birdseed', 'consonance', 'emirate', 'athelia', 'transact', 'symmetrically',
    'precomparison', 'capetown', 'sittidae', 'chunkier', 'cassolette',
    'blockader', 'ludicrous', 'bribe', 'suddens', 'flachery', 'represented',
    'undialled', 'porpoise', 'speer', 'biologists', 'balunda', 'chipped',
    'minicar', 'impulsively', 'boroughs', 'quizzify', 'differentiator',
    'cornada', 'catalysis', 'wasp', 'soaplees', 'arracacha', 'primordality',
    'sheriff', 'melangeur', 'badly', 'neglectingly', 'synaxes', 'proscriptive',
    'convict', 'capturer', 'eidetic', 'bitton', 'tryptone', 'rille',
    'subplantigrade', 'nonviscous', 'eladio', 'wampum', 'earwig', 'aerobatics',
    'centenary', 'avestan', 'afrikaans', 'unipartite', 'skreel', 'collegium',
    'sarges', 'misentreat', 'drenched', 'trippet', 'perchlorinate',
    'coffeehouse', 'advertised', 'alegre', 'blamably', 'remittances',
    'wonderful', 'imprudential', 'spiracular', 'cartesian', 'demur',
    'impertinentness', 'cavum', 'cyanite', 'conformations', 'containerize',
    'brayed', 'interflow', 'nobelist', 'starfish', 'funambulatory',
    'verbigeration', 'unicapsular', 'syrupy', 'aggression', 'flattop', 'corban',
    'cellule', 'raddle', 'diptera', 'caesar', 'anisodactyle', 'evens',
    'existential', 'zaffre', 'breaded', 'vanished', 'torpor', 'araneid',
    'stodger', 'basiophthalmite', 'dowse', 'whippet', 'agent', 'gombeen',
    'eurytropic', 'nordenfelt', 'nucleary', 'cotys', 'castilian', 'blowing',
    'nonradiable', 'vestiaries', 'dielike', 'norms', 'tetra', 'cames', 'locust',
    'immerging', 'aurevoir', 'uprooter', 'gut', 'bred', 'contrafagotto',
    'reuttering', 'tewing', 'papulation', 'persuadingly', 'purdah', 'mink',
    'barmecide', 'ferret', 'alliya', 'waugh', 'cailliach', 'ladybugs',
    'rabbitmouth', 'cumulate', 'elided', 'micronuclear', 'exacter', 'banda',
    'coleslaw', 'silanes', 'aiglet', 'calcinosis', 'undistant', 'porcupine',
    'unprematureness', 'enkidu', 'unknots', 'anticlassicalist', 'extravert',
    'alexis', 'timaliine', 'raphia', 'phosphate', 'albanians', 'scraps',
    'mirth', 'seawant', 'brandie', 'carlyle', 'cruche', 'angostura',
    'nonderogation', 'reelect', 'mislabor', 'exogen', 'tilak', 'victorianism',
    'astoria', 'increaseful', 'erode', 'senary', 'rhinoplasty', 'beaux',
    'undemocratized', 'gerbil', 'delila', 'quietens', 'turkey', 'megalomaniac',
    'pinwheel', 'promorphologist', 'btl', 'speron', 'apolline', 'aeonian',
    'sirvent', 'champ', 'adiana', 'riotise', 'portment', 'neurocity',
    'undergabble', 'choler', 'subatom', 'chilicote', 'uranite',
    'vinylacetylene', 'demotes', 'bergaptene', 'anamorphose', 'adventuring',
    'asouth', 'palaeoalchemical', 'lavinia', 'anybodies', 'argento', 'unacted',
    'corium', 'abstracted', 'unawakableness', 'downhills', 'esparto', 'gripy',
    'dogged', 'uguisu', 'empathetic', 'piffles', 'cautivo', 'reconvenes',
    'chechen', 'buffalo', 'immolator', 'believe', 'ashlie', 'outspanning',
    'outlandish', 'thiobismuthite', 'carine', 'crivetz', 'sensoparalysis',
    'locoed', 'bourreau', 'belie', 'streeking', 'unwillfully', 'cougar',
    'eyeline', 'wipers', 'retestifying', 'vedism', 'ceibo', 'myalgic', 'bobbee',
    'installation', 'kilograin', 'rabboni', 'cacara', 'iglu', 'splendiferous',
    'navies', 'burel', 'ag', 'potentize', 'overlow', 'arethusa', 'paperweight',
    'pipits', 'benjamite', 'battlers', 'unadoptive', 'groten', 'turtle', 'mate',
    'floral', 'cornual', 'birendra', 'killing', 'strolling', 'eleazar',
    'unnomadically', 'temporooccipital', 'demons', 'arras', 'huddlingly',
    'naturalistic', 'chytridial', 'eyewink', 'arthritis', 'emacs', 'gals',
    'profaners', 'coldish', 'docken', 'foeship', 'pasha', 'adventurous',
    'brooklyn', 'unalimentative', 'methylacetanilide', 'invite', 'benzalazine',
    'penguin', 'brightly', 'chemoreceptor', 'osmanthus', 'forrard', 'bird',
    'wingy', 'soh', 'derates', 'heiress', 'untended', 'ababa', 'silaginoid',
    'linemen', 'ungambolled', 'cense', 'capitation', 'silhouette', 'tinfoil',
    'escalader', 'merycism', 'beasts', 'finalist', 'undertenancy', 'downcome',
    'exfoliate', 'gingeleys', 'morpho', 'vertebras', 'dislimns',
    'unsurrealistic', 'ailuropus', 'cutlet', 'coventries', 'incaliculate',
    'salar', 'dewberry', 'parridge', 'loads', 'progression', 'cosmorama',
    'astral', 'hemimetabola', 'atopy', 'butta', 'sulphoselenide', 'elvira',
    'chuckies', 'stylobata', 'banky', 'ensign', 'acromegalies',
    'undistrustfulness', 'boilerman', 'raincoat', 'rurally', 'quebrachos',
    'kiwifruit', 'spermatogenesis', 'chengwei', 'cycles', 'interossei',
    'climber', 'coogan', 'crosse', 'dingbats', 'exordia', 'cablet', 'bagels',
    'creatine', 'fastening', 'airtight', 'duck', 'whammo', 'indisciplinable',
    'clitia', 'unfeignedness', 'undercount', 'scorch', 'soling', 'cliffs',
    'dropping', 'disembroilment', 'mantoid', 'artaba', 'paediatric', 'giddier',
    'succursal', 'haplome', 'batster', 'precast', 'bathe', 'cathole',
    'billable', 'madras', 'codicil', 'nightingale', 'razers', 'alvarez',
    'copperfield', 'condiction', 'rewards', 'pelecypoda', 'brahms', 'tirl',
    'absolute', 'livering', 'pedicle', 'patrist', 'seduced', 'apophysis',
    'cynicalness', 'dewit', 'mistermed', 'boden', 'beebe', 'palaeocrinoidea',
    'staunching', 'decency', 'applejack', 'dight', 'civies', 'martello',
    'chandan', 'antilytic', 'unicotyledonous', 'accable', 'invigoration',
    'starling', 'tricostate', 'cordy', 'scuzzy', 'belich', 'kudu', 'confab',
    'cudden', 'morular', 'schipperke', 'shawm', 'copyist', 'patness', 'ourang',
    'daylights', 'indecency', 'caterpillar', 'dodo', 'carrefour', 'hymenium',
    'fossa', 'velocipeding', 'dusky', 'wonders', 'blacky', 'average', 'boiko',
    'falcon', 'posadaship', 'transubstantiate', 'coquillage', 'lefty',
    'anthropos', 'unjewelled', 'depict', 'snail', 'aouad', 'denominate',
    'elberta', 'bumfs', 'compatriot', 'decrepit', 'huajillo', 'byroad',
    'ninjas', 'stylar', 'outlivers', 'rudimentary', 'rondawel', 'rhythmically',
    'arranger', 'proscind', 'decimolar', 'bunkoed', 'phloxes', 'kolhoz',
    'lobations', 'auricularia', 'siberian', 'diploptera', 'razzmatazz',
    'definitised', 'loupes', 'saxes', 'pinole', 'dined', 'microphytology',
    'comix', 'boondoggling', 'prostitute', 'oximetry', 'depraved', 'zebra',
    'isopoda', 'convected', 'convolvulus', 'bastille', 'infectionist',
    'animated', 'puffin', 'secretive', 'dingdonging', 'carburator',
    'introconversion', 'saintdom', 'nonbelief', 'unsolicited', 'boreades',
    'soldierwood', 'streptothrix', 'terrorized', 'kabistan', 'flowable',
    'baskin', 'unlimned', 'braunschweiger', 'unniceness', 'dassent',
    'hysterodynia', 'flapping', 'inspired', 'supervene', 'complement', 'ester',
    'tableau', 'philepitta', 'cheeking', 'baldric', 'acubens', 'castiron',
    'celtish', 'jeoparding', 'gunsmithing', 'afterspeech', 'stingray',
    'carmina', 'blending', 'semblance', 'restrains', 'laurvikite', 'mornings',
    'oversubscribing', 'sycophantry', 'boar', 'cardia', 'darrel', 'shove',
    'cruise', 'angelo', 'atop', 'unprofaned', 'ch', 'donnie', 'fumigation',
    'scriptures', 'dorelia', 'chafeweed', 'intertarsal', 'daekon', 'pantryman',
    'carbonated', 'amstutz', 'snake', 'piscators', 'gambet', 'connelly',
    'biggonet', 'alessand', 'episarkine', 'squid', 'orthostatic', 'scapulopexy',
    'chigger', 'datura', 'drainpipe', 'blaze', 'calamine', 'broccoli',
    'streamiest', 'deranger', 'unmercifully', 'extravagate', 'dinosaur',
    'anaesthesis', 'brockie', 'thimblerigger', 'rubeola', 'beachcomber',
    'washy', 'dinners', 'anthracnose', 'befits', 'hippuridaceae', 'ashleigh',
    'annoying', 'cohabitants', 'lollygag', 'borneo', 'submanic', 'going',
    'doubts', 'crankless', 'telepathically', 'dubose', 'cleancut',
    'reimpregnating', 'gubernacular', 'acrite', 'sundayism', 'binda', 'carlene',
    'abashed', 'vocalist', 'panthers', 'hamamelidanthemum', 'anthroxan',
    'bunni', 'capelin', 'halomorphic', 'unconflicting', 'dentelle', 'wallaby',
    'calcutta', 'scaldweed', 'burgesses', 'april', 'assistant', 'scams',
    'electrodes', 'corporateness', 'incognitos', 'akita', 'sorriness',
    'rushland', 'carnivore', 'electrocute', 'bohdan', 'segueing', 'simplum',
    'scampers', 'capistrano', 'chigetais', 'thousand', 'flowerer',
    'albificative', 'undefiniteness', 'wren', 'disjointedness', 'anthuriums',
    'buffoonish', 'legator', 'greengage', 'avenger', 'gorilla', 'starvation',
    'conger', 'murras', 'tovar', 'motorman', 'sandpiper', 'antsy', 'dishrag',
    'fireworkless', 'alcalde', 'eskar', 'dadaism', 'satd', 'cassowary',
    'parsed', 'constructor', 'latipennate', 'dutuburi', 'birman', 'coranto',
    'lovers', 'deperition', 'corporeal', 'blasted', 'shad', 'sequined',
    'thumps', 'bridal', 'creating', 'intervallum', 'cites', 'monotheistically',
    'tonlet', 'bloomed', 'paleichthyology', 'scarlet', 'etymologised',
    'foreshoulder', 'dipietro', 'clatty', 'saturants', 'bedding', 'ernestine',
    'zoroaster', 'cassondra', 'plantula', 'craze', 'frangent', 'oxalyl',
    'rugal', 'dhoul', 'bidden', 'assault', 'tumion', 'shipwrecky', 'ambrette',
    'soave', 'contemp', 'orchestric', 'maltese', 'ander', 'dalcassian',
    'heeler', 'buttermaker', 'bocoy', 'donga', 'unsanctifying', 'saarbrucken',
    'aspidium', 'fewer', 'wolverine', 'tilled', 'anemony', 'amentulum',
    'brabblingly', 'kobus', 'abrasax', 'shadowgraphy', 'agitprop', 'hoidening',
    'preexposes', 'whitier', 'rumpus', 'stonemason', 'zootaxy', 'bilio',
    'adverted', 'criticaster', 'coremaker', 'complainers', 'winterberry',
    'bear', 'bezzo', 'vivers', 'abalone', 'convolutedly', 'conservative',
    'alshain', 'landmark', 'bloodless', 'pronephros', 'unstoicize', 'faller',
    'lifer', 'accidia', 'loment', 'ineradicability', 'vibratile', 'oddballs',
    'larding', 'octopus', 'aldus', 'proteides', 'alfred', 'angioleucitis',
    'abaft', 'exhibits', 'toucan', 'longlines', 'photographic', 'tradition',
    'shadchan', 'undermarshalmen', 'regains', 'chipchap', 'caprice',
    'unebriate', 'sonorosity', 'sailable', 'anterograde', 'magistral', 'moped',
    'arrays', 'stacker', 'spiritually', 'ballate', 'adriaan', 'vandalic',
    'careworn', 'brachial', 'clepsydra', 'internal', 'alcoholic', 'altiplano',
    'manerial', 'caking', 'backpacker', 'ibis', 'pleonastic', 'brushwood',
    'amorphia', 'chylification', 'fatback', 'tochered', 'diene', 'amuck',
    'corporations', 'ahead', 'basco', 'mitten', 'flamer', 'peafowl', 'fogger',
    'protococcales', 'coati', 'creen', 'corena', 'optimacy', 'suprastandard',
    'globalism', 'bonanzas', 'tingler', 'ringdoves', 'archsewer', 'bullhorn',
    'pantopterous', 'carbonite', 'calamite', 'strifes', 'vegetation',
    'silentest', 'metalsmith', 'wingding', 'breakthrough', 'aldols',
    'cantankerousness', 'reflating', 'seemly', 'syntelome', 'septembral',
    'escudero', 'christianson', 'pilgrim', 'chaka', 'adown', 'chromo', 'novela',
    'estelle', 'jeopardise', 'apogon', 'incumber', 'arles', 'dangle', 'demarch',
    'astrologistic', 'pseudovum', 'brody', 'cenozoic', 'batwa', 'arbacia',
    'zeuzera', 'suing', 'geonoma', 'evehood', 'apritif', 'multifilament',
    'airish', 'allan', 'equilibrio', 'hollyhocks', 'wronghead', 'whimbrels',
    'osmundaceae', 'andira', 'thunderstorm', 'preinspired', 'broadmouth',
    'aindrea', 'arming', 'carita', 'clinic', 'blame', 'chemosynthesis',
    'classifier', 'reviviscency', 'casco', 'investible', 'excitor', 'parterres',
    'consimilating', 'prowling', 'marten', 'constanta', 'latuka', 'euphonism',
    'wound', 'peelings', 'malgrado', 'adermia', 'bruise', 'artery', 'firearms',
    'comfit', 'goodwill', 'caulicles', 'precisionize', 'allen', 'valours',
    'canyon', 'bicamerist', 'desmopyknosis', 'diktat', 'brainwasher', 'litotes',
    'imprejudice', 'gnat', 'welcomely', 'embryon', 'poodle', 'catchpole',
    'culch', 'fiction', 'belight', 'anglophilia', 'scarfwise', 'appellations',
    'slavophile', 'coerced', 'hydrograph', 'alexandrite', 'repours', 'ayoup',
    'featherfew', 'occipitoiliac', 'waftage', 'decembrist', 'unideographically',
    'gregarina', 'ancestry', 'determinant', 'riverhead', 'allay', 'pulsific',
    'brassard', 'preposed', 'huashi', 'bickford', 'toprail',
    'nonmarriageableness', 'too', 'archeus', 'fatuities', 'campbell',
    'noncorrelating', 'turnsoles', 'fabio', 'continuingly', 'cow', 'bandicoot',
    'barklyite', 'epigrammatic', 'unstocking', 'baboon', 'allstate', 'tonic',
    'strenuous', 'azhar', 'choluteca', 'earring', 'chaja', 'arleng',
    'oreophasine', 'sevennight', 'belanda', 'circadian', 'axonophora',
    'unsaturation', 'adolphe', 'deliquescent', 'snakebite', 'daube',
    'stimulancy', 'thermometrically', 'adirondack', 'algerine', 'meatmen',
    'excalibur', 'necrobacillary', 'pulvinus', 'bat',
]

SOCIAL_NETWORKS = {
    'facebook': 'facebook.com/{}',
    'twitter': 'twitter.com/{}',
    'instagram': 'instagram.com/{}',
    'vk': 'vk.com/{}',
}



# -*- coding: utf-8 -*-

"""Specific data provider for Ukraine (uk)."""

from mimesis.builtins.base import BaseSpecProvider
from mimesis.enums import Gender
from mimesis.typing import Seed

__all__ = ['UkraineSpecProvider']


class UkraineSpecProvider(BaseSpecProvider):
    """Class that provides special data for Ukraine (uk)."""

    def __init__(self, seed: Seed = None):
        """Initialize attributes."""
        super().__init__(locale='uk', seed=seed)
        self.pull(self._datafile)

    class Meta:
        """The name of the provider."""

        name = 'ukraine_provider'

    def patronymic(self, gender: Gender = None) -> str:
        """Generate random patronymic name.

        :param gender: Gender of person.
        :type gender: str or int
        :return: Patronymic name.
        """
        gender = self._validate_enum(gender, Gender)
        patronymics = self._data['patronymic'][gender]
        return self.random.choice(patronymics)



# -*- coding: utf-8 -*-

"""This module provides constants for locale-dependent providers."""

CS = 'cs'
DA = 'da'
DE = 'de'
DE_AT = 'de-at'
DE_CH = 'de-ch'
EL = 'el'
EN = 'en'
EN_AU = 'en-au'
EN_CA = 'en-ca'
EN_GB = 'en-gb'
ES = 'es'
ES_MX = 'es-mx'
ET = 'et'
FA = 'fa'
FI = 'fi'
FR = 'fr'
HU = 'hu'
IS = 'is'
IT = 'it'
JA = 'ja'
KK = 'kk'
KO = 'ko'
NL = 'nl'
NL_BE = 'nl-be'
NO = 'no'
PL = 'pl'
PT = 'pt'
PT_BR = 'pt-br'
RU = 'ru'
SV = 'sv'
TR = 'tr'
UK = 'uk'
ZH = 'zh'

DEFAULT_LOCALE = EN

SUPPORTED_LOCALES = {
    CS: {
        'name': 'Czech',
        'name_local': 'česky',
    },
    DA: {
        'name': 'Danish',
        'name_local': 'Dansk',
    },
    DE: {
        'name': 'German',
        'name_local': 'Deutsch',
    },
    DE_AT: {
        'name': 'Austrian German',
        'name_local': 'Deutsch',
    },
    DE_CH: {
        'name': 'Swiss German',
        'name_local': 'Deutsch',
    },
    EL: {
        'name': 'Greek',
        'name_local': 'Ελληνικά',
    },
    EN: {
        'name': 'English',
        'name_local': 'English',
    },
    EN_GB: {
        'name': 'British English',
        'name_local': 'English',
    },
    EN_AU: {
        'name': 'Australian English',
        'name_local': 'English',
    },
    EN_CA: {
        'name': 'Canadian English',
        'name_local': 'English',
    },
    ES: {
        'name': 'Spanish',
        'name_local': 'Español',
    },
    ES_MX: {
        'name': 'Mexican Spanish',
        'name_local': 'Español',
    },
    ET: {
        'name': 'Estonian',
        'name_local': 'Eesti',
    },
    FA: {
        'name': 'Farsi',
        'name_local': 'فارسی',
    },
    FI: {
        'name': 'Finnish',
        'name_local': 'Suomi',
    },
    FR: {
        'name': 'French',
        'name_local': 'Français',
    },
    HU: {
        'name': 'Hungarian',
        'name_local': 'Magyar',
    },
    IS: {
        'name': 'Icelandic',
        'name_local': 'Íslenska',
    },
    IT: {
        'name': 'Italian',
        'name_local': 'Italiano',
    },
    JA: {
        'name': 'Japanese',
        'name_local': '日本語',
    },
    KK: {
        'name': 'Kazakh',
        'name_local': 'Қазақша',
    },
    KO: {
        'name': 'Korean',
        'name_local': '한국어',
    },
    NL: {
        'name': 'Dutch',
        'name_local': 'Nederlands',
    },
    NL_BE: {
        'name': 'Belgium Dutch',
        'name_local': 'Nederlands',
    },
    NO: {
        'name': 'Norwegian',
        'name_local': 'Norsk',
    },
    PL: {
        'name': 'Polish',
        'name_local': 'Polski',
    },
    PT: {
        'name': 'Portuguese',
        'name_local': 'Português',
    },
    PT_BR: {
        'name': 'Brazilian Portuguese',
        'name_local': 'Português Brasileiro',
    },
    RU: {
        'name': 'Russian',
        'name_local': 'Русский',
    },
    SV: {
        'name': 'Swedish',
        'name_local': 'Svenska',
    },
    TR: {
        'name': 'Turkish',
        'name_local': 'Türkçe',
    },
    UK: {
        'name': 'Ukrainian',
        'name_local': 'Українська',
    },
    ZH: {
        'name': 'Chinese',
        'name_local': '汉语',
    },
}

LIST_OF_LOCALES = list(SUPPORTED_LOCALES)
LOCALE_SEPARATOR = '-'



# -*- coding: utf-8 -*-

"""Specific data provider for Russia (ru)."""

from mimesis.builtins.base import BaseSpecProvider
from mimesis.enums import Gender
from mimesis.typing import Seed

__all__ = ['RussiaSpecProvider']


class RussiaSpecProvider(BaseSpecProvider):
    """Class that provides special data for Russia (ru)."""

    def __init__(self, seed: Seed = None):
        """Initialize attributes."""
        super().__init__(locale='ru', seed=seed)
        self.pull(self._datafile)

    class Meta:
        """The name of the provider."""

        name = 'russia_provider'

    def generate_sentence(self) -> str:
        """Generate sentence from the parts.

        :return: Sentence.
        """
        sentences = self._data['sentence']
        sentence = [
            self.random.choice(sentences[k]) for k
            in ('head', 'p1', 'p2', 'tail')
        ]
        return '{0} {1} {2} {3}'.format(*sentence)

    def patronymic(self, gender: Gender = None) -> str:
        """Generate random patronymic name.

        :param gender: Gender of person.
        :return: Patronymic name.

        :Example:
            Алексеевна.
        """
        gender = self._validate_enum(gender, Gender)
        patronymics = self._data['patronymic'][gender]
        return self.random.choice(patronymics)

    def passport_series(self, year: int = None) -> str:
        """Generate random series of passport.

        :param year: Year of manufacture.
        :type year: int or None
        :return: Series.

        :Example:
            02 15.
        """
        if not year:
            year = self.random.randint(10, 18)

        region = self.random.randint(1, 99)
        return '{:02d} {}'.format(region, year)

    def passport_number(self) -> int:
        """Generate random passport number.

        :return: Number.

        :Example:
            560430
        """
        return self.random.randint(
            100000, 999999)

    def series_and_number(self) -> str:
        """Generate a random passport number and series.

        :return: Series and number.

        :Example:
            57 16 805199.
        """
        return '{}{}'.format(
            self.passport_series(),
            self.passport_number(),
        )

    def snils(self) -> str:
        """Generate snils with special algorithm.

        :return: SNILS.

        :Example:
            41917492600.
        """
        numbers = []
        control_codes = []

        for i in range(0, 9):
            numbers.append(self.random.randint(0, 9))

        for i in range(9, 0, -1):
            control_codes.append(numbers[9 - i] * i)

        control_code = sum(control_codes)
        code = ''.join(str(number) for number in numbers)

        if control_code in (100, 101):
            snils = code + '00'
            return snils

        if control_code < 100:
            snils = code + str(control_code)
            return snils

        if control_code > 101:
            control_code = control_code % 101
            if control_code == 100:
                control_code = 0
            snils = code + '{:02}'.format(control_code)
            return snils

    def inn(self) -> str:
        """Generate random, but valid ``INN``.

        :return: INN.
        """
        def control_sum(nums: list, t: str) -> int:
            digits = {
                'n2': [7, 2, 4, 10, 3, 5, 9, 4, 6, 8],
                'n1': [3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8],
            }
            number = 0
            length = digits[t]
            for i in range(0, len(length)):
                number += nums[i] * length[i]
            return number % 11 % 10

        numbers = []
        for x in range(0, 10):
            numbers.append(self.random.randint(1 if x == 0 else 0, 9))

        n2 = control_sum(numbers, 'n2')
        numbers.append(n2)
        n1 = control_sum(numbers, 'n1')
        numbers.append(n1)
        return ''.join([str(x) for x in numbers])

    def ogrn(self) -> str:
        """Generate random valid ``OGRN``.

        :return: OGRN.

        :Example:
            4715113303725.
        """
        numbers = []
        for _ in range(0, 12):
            numbers.append(self.random.randint(1 if _ == 0 else 0, 9))

        ogrn = ''.join([str(x) for x in numbers])
        check_sum = str(int(ogrn) % 11 % 10)

        return '{}{}'.format(ogrn, check_sum)

    def bic(self) -> str:
        """Generate random ``BIC`` (Bank ID Code).

        :return: BIC.

        :Example:
            044025575.
        """
        country_code = '04'
        code = '{:02}'.format(self.random.randint(1, 10))
        bank_number = '{:02}'.format(self.random.randint(0, 99))
        bank_office = '{:03}'.format(self.random.randint(50, 999))
        bic = country_code + code + bank_number + bank_office
        return bic

    def kpp(self) -> str:
        """Generate random ``KPP``.

        :return: 'KPP'.

        :Example:
            560058652.
        """
        tax_codes = [
            '7700', '7800', '5000', '0100',
            '0200', '0300', '0500', '0600',
            '0700', '0800', '0900', '1000',
            '1100', '1200', '1300', '1400',
            '1500', '1600', '1700', '1800',
            '1900', '2000', '2100', '2200',
            '2300', '2400', '2500', '2600',
            '2700', '2800', '2900', '3000',
            '3100', '3200', '3300', '3400',
            '3500', '3600', '3700', '3800',
            '3900', '4000', '4100', '4900',
            '5100', '5200', '5300', '5400',
            '5500', '5600', '5700', '5800',
            '5900', '6000', '6100', '6200',
            '6300', '6400', '6500', '6600',
            '6700', '6800', '6900', '7000',
            '7100', '7200', '7300', '7400',
            '7500', '7600', '7900', '8600',
            '8700', '8900', '9100', '9200',
            '9800', '9900', '9901', '9951',
            '9952', '9953', '9954', '9955',
            '9956', '9957', '9958', '9959',
            '9961', '9962', '9965', '9966',
            '9971', '9972', '9973', '9974',
            '9975', '9976', '9977', '9979',
            '9998',
        ]

        tax_code = tax_codes[self.random.randint(0, len(tax_codes) - 1)]
        reg_code = '{:02}'.format(self.random.randint(1, 99))
        reg_number = '{:03}'.format(self.random.randint(1, 999))
        kpp = tax_code + reg_code + reg_number
        return kpp



# -*- coding: utf-8 -*-

"""Specific data provider for Poland (pl)."""

from mimesis.builtins.base import BaseSpecProvider
from mimesis.enums import Gender
from mimesis.providers import Datetime
from mimesis.typing import DateTime, Seed

__all__ = ['PolandSpecProvider']


class PolandSpecProvider(BaseSpecProvider):
    """Class that provides special data for Poland (pl)."""

    def __init__(self, seed: Seed = None):
        """Initialize attributes."""
        super().__init__(locale='pl', seed=seed)

    class Meta:
        """The name of the provider."""

        name = 'poland_provider'

    def nip(self) -> str:
        """Generate random valid 10-digit NIP.

        :return: Valid 10-digit NIP
        """
        nip_digits = [int(d) for d in str(self.random.randint(101, 998))]
        nip_digits += [self.random.randint(0, 9) for _ in range(6)]
        nip_coefficients = (6, 5, 7, 2, 3, 4, 5, 6, 7)
        sum_v = sum([nc * nd for nc, nd in
                     zip(nip_coefficients, nip_digits)])

        checksum_digit = sum_v % 11
        if checksum_digit > 9:
            return self.nip()
        nip_digits.append(checksum_digit)
        return ''.join(str(d) for d in nip_digits)

    def pesel(self, birth_date: DateTime = None,
              gender: Gender = None) -> str:
        """Generate random 11-digit PESEL.

        :param birth_date: Initial birth date (optional)
        :param gender: Gender of person
        :return: Valid 11-digit PESEL
        """
        date_object = birth_date
        if not date_object:
            date_object = Datetime().datetime(1940, 2018)

        year = date_object.date().year
        month = date_object.date().month
        day = date_object.date().day
        pesel_digits = [int(d) for d in str(year)][-2:]

        if 1800 <= year <= 1899:
            month += 80
        elif 2000 <= year <= 2099:
            month += 20
        elif 2100 <= year <= 2199:
            month += 40
        elif 2200 <= year <= 2299:
            month += 60

        pesel_digits += [int(d) for d in '{:02d}'.format(month)]
        pesel_digits += [int(d) for d in '{:02d}'.format(day)]
        series_number = self.random.randint(0, 999)
        pesel_digits += [int(d) for d in '{:03d}'.format(series_number)]

        if gender == Gender.MALE:
            gender_digit = self.random.choice((1, 3, 5, 7, 9))
        elif gender == Gender.FEMALE:
            gender_digit = self.random.choice((0, 2, 4, 6, 8))
        else:
            gender_digit = self.random.choice(range(10))

        pesel_digits.append(gender_digit)
        pesel_coeffs = (9, 7, 3, 1, 9, 7, 3, 1, 9, 7)
        sum_v = sum([nc * nd for nc, nd in
                     zip(pesel_coeffs, pesel_digits)])
        checksum_digit = sum_v % 10
        pesel_digits.append(checksum_digit)
        return ''.join(str(d) for d in pesel_digits)

    def regon(self) -> str:
        """Generate random valid 9-digit REGON.

        :return: Valid 9-digit REGON
        """
        regon_coeffs = (8, 9, 2, 3, 4, 5, 6, 7)
        regon_digits = [self.random.randint(0, 9) for _ in range(8)]
        sum_v = sum([nc * nd for nc, nd in
                     zip(regon_coeffs, regon_digits)])
        checksum_digit = sum_v % 11
        if checksum_digit > 9:
            checksum_digit = 0
        regon_digits.append(checksum_digit)
        return ''.join(str(d) for d in regon_digits)



# -*- coding: utf-8 -*-

"""Implements classes for generating data by schema."""

from types import LambdaType
from typing import Any, Callable, List, Optional

from mimesis.exceptions import (
    UnacceptableField,
    UndefinedField,
    UndefinedSchema,
    UnsupportedField,
)
from mimesis.providers.generic import Generic
from mimesis.typing import JSON, Seed

__all__ = ['AbstractField', 'Field', 'Schema']


class AbstractField(object):
    """
    AbstractField is a class for generating data by the name of the method.

    Instance of this object takes any string which represents name
    of any method of any supported data provider (:class:`~mimesis.Generic`)
    and the ``**kwargs`` of the method:

    >>> _ = AbstractField('en', 0xf)
    >>> surname = _('surname')
    >>> isinstance(surname, str)
    True
    """

    def __init__(self, locale: str = 'en',
                 seed: Optional[Seed] = None,
                 providers: Optional[Any] = None) -> None:
        """Initialize field.

        :param locale: Locale
        :param seed: Seed for random.
        """
        self.locale = locale
        self.seed = seed
        self._gen = Generic(self.locale, self.seed)

        if providers:
            self._gen.add_providers(*providers)

        self._table = {}  # type: ignore

    def __call__(self, name: Optional[str] = None,
                 key: Optional[Callable] = None, **kwargs) -> Any:
        """Override standard call.

        This magic method override standard call so it's take any string which
        represents name of the any method of any supported data provider
        and the ``**kwargs`` of this method.

        ..note:: Some data providers have methods with the same name and
        in such cases, you can explicitly define that the method belongs to
        data-provider ``name='provider.name'``.

        You can apply a *key function* to result returned by the method,
        to do it, just pass parameter **key** with a callable object which
        returns final result.

        :param name: Name of the method.
        :param key: A key function (or other callable object)
            which will be applied to result.
        :param kwargs: Kwargs of method.
        :return: Value which represented by method.
        :raises ValueError: if provider is not
            supported or if field is not defined.
        """
        if name is None:
            raise UndefinedField()

        def tail_parser(tails: str, obj: Any) -> Any:
            """Return method from end of tail.

            :param tails: Tail string
            :param obj: Search tail from this object
            :return last tailed method
            """
            provider_name, method_name = tails.split('.', 1)

            if '.' in method_name:
                raise UnacceptableField()

            attr = getattr(obj, provider_name)
            if attr is not None:
                return getattr(attr, method_name)

        try:
            if name not in self._table:
                if '.' not in name:
                    # Fix https://github.com/lk-geimfari/mimesis/issues/619
                    if name == self._gen.choice.Meta.name:
                        self._table[name] = self._gen.choice
                    else:
                        for provider in dir(self._gen):
                            provider = getattr(self._gen, provider)
                            if name in dir(provider):
                                self._table[name] = getattr(provider, name)
                else:
                    self._table[name] = tail_parser(name, self._gen)

            result = self._table[name](**kwargs)
            if key and callable(key):
                return key(result)
            return result
        except KeyError:
            raise UnsupportedField(name)

    def __str__(self):
        return '{} <{}>'.format(
            self.__class__.__name__, self.locale)


class Schema(object):
    """Class which return list of filled schemas."""

    def __init__(self, schema: LambdaType) -> None:
        """Initialize schema.

        :param schema: A schema.
        """
        if isinstance(schema, LambdaType):
            self.schema = schema
        else:
            raise UndefinedSchema()

    def create(self, iterations: int = 1) -> List[JSON]:
        """Return filled schema.

        Create a list of a filled schemas with elements in
        an amount of **iterations**.

        :param iterations: Amount of iterations.
        :return: List of willed schemas.
        """
        return [self.schema() for _ in range(iterations)]


# Alias for AbstractField
Field = AbstractField
